@@ -1,6 +1,6 @@
 #!bin/sh
 
-kdenlive_subdirs="plugins renderer src src/widgets"
+kdenlive_subdirs="plugins renderer src src/ui"
 
 $EXTRACTRC --tag=name --tag=description --tag=label --tag=comment --tag=paramlistdisplay effects/*.xml data/kdenliveeffectscategory.rc >> rc.cpp
 $EXTRACTRC `find $kdenlive_subdirs -name \*.rc -a ! -name encodingprofiles.rc -o -name \*.ui` >> rc.cpp
