@@ -23,7 +23,7 @@
 #include "kdenlivesettings.h"
 
 #include <KDebug>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KGlobalSettings>
 
 #include <QPainter>
@@ -122,7 +122,7 @@ GenTime AbstractClipItem::cropDuration() const
     return m_info.cropDuration;
 }
 
-void AbstractClipItem::setCropStart(GenTime pos)
+void AbstractClipItem::setCropStart(const GenTime &pos)
 {
     m_info.cropStart = pos;
 }
@@ -143,7 +143,7 @@ void AbstractClipItem::resizeStart(int posx, bool hasSizeLimit, bool /*emitChang
     GenTime durationDiff = GenTime(posx, m_fps) - m_info.startPos;
     if (durationDiff == GenTime()) return;
 
-    if (type() == AVWIDGET && hasSizeLimit && (cropStart() + durationDiff < GenTime())) {
+    if (type() == AVWidget && hasSizeLimit && (cropStart() + durationDiff < GenTime())) {
         durationDiff = GenTime() - cropStart();
     } else if (durationDiff >= cropDuration()) {
         return;
@@ -154,7 +154,7 @@ void AbstractClipItem::resizeStart(int posx, bool hasSizeLimit, bool /*emitChang
 
     // set to true if crop from start is negative (possible for color clips, images as they have no size limit)
     bool negCropStart = false;
-    if (type() == AVWIDGET) {
+    if (type() == AVWidget) {
         m_info.cropStart += durationDiff;
         if (m_info.cropStart < GenTime())
             negCropStart = true;
@@ -168,7 +168,7 @@ void AbstractClipItem::resizeStart(int posx, bool hasSizeLimit, bool /*emitChang
         //kDebug() << "//////  WARNING, DIFF IN XPOS: " << pos().x() << " == " << m_info.startPos.frames(m_fps);
         GenTime diff = m_info.startPos - GenTime(posx, m_fps);
 
-        if (type() == AVWIDGET)
+        if (type() == AVWidget)
             m_info.cropStart += diff;
 
         m_info.cropDuration -= diff;
@@ -193,7 +193,7 @@ void AbstractClipItem::resizeStart(int posx, bool hasSizeLimit, bool /*emitChang
                     setRect(0, 0, (m_cropDuration - diff).frames(m_fps) - 0.02, rect().height());
                     setPos((m_startPos + diff).frames(m_fps), pos().y());
                     m_startPos += diff;
-                    if (type() == AVWIDGET) m_cropStart += diff;
+                    if (type() == AVWidget) m_cropStart += diff;
                     m_cropDuration = m_cropDuration - diff;
                     break;
                 }
@@ -223,7 +223,7 @@ void AbstractClipItem::resizeEnd(int posx, bool /*emitChange*/)
                 //kDebug() << "/////////  COLLISION DETECTED!!!!!!!!!";
                 //kDebug() << "/////////  CURRENT: " << startPos().frames(25) << "x" << endPos().frames(25) << ", RECT: " << rect() << "-" << pos();
                 //kDebug() << "/////////  COLLISION: " << ((AbstractClipItem *)item)->startPos().frames(25) << "x" << ((AbstractClipItem *)item)->endPos().frames(25) << ", RECT: " << ((AbstractClipItem *)item)->rect() << "-" << item->pos();
-                GenTime diff = ((AbstractClipItem *)item)->startPos() - startPos();
+                GenTime diff = static_cast<AbstractClipItem*>(item)->startPos() - startPos();
                 if (fixItem == false || diff < m_info.cropDuration) {
                     fixItem = true;
                     m_info.cropDuration = diff;
@@ -261,7 +261,7 @@ GenTime AbstractClipItem::maxDuration() const
     return m_maxDuration;
 }
 
-void AbstractClipItem::drawKeyFrames(QPainter *painter, const QTransform transformation, bool limitedKeyFrames)
+void AbstractClipItem::drawKeyFrames(QPainter *painter, const QTransform &transformation, bool limitedKeyFrames)
 {
     if (m_keyframes.count() < 1)
         return;
@@ -279,7 +279,7 @@ void AbstractClipItem::drawKeyFrames(QPainter *painter, const QTransform transfo
         x2 = br.right();
         if (limitedKeyFrames) {
             QMap<int, int>::const_iterator end = m_keyframes.constEnd();
-            end--;
+            --end;
             x2 = x1 + maxw * (end.key() - start);
             x1 += maxw * (m_keyframes.constBegin().key() - start);
         }
@@ -357,11 +357,9 @@ int AbstractClipItem::mouseOverKeyFrames(QPointF pos, double maxOffset)
     double maxh = br.height() / 100.0 * m_keyframeFactor;
     if (m_keyframes.count() > 0) {
         QMap<int, int>::const_iterator i = m_keyframes.constBegin();
-        double x1;
-        double y1;
         while (i != m_keyframes.constEnd()) {
-            x1 = br.x() + maxw * (i.key() - cropStart().frames(m_fps));
-            y1 = br.bottom() - (i.value() - m_keyframeOffset) * maxh;
+            double x1 = br.x() + maxw * (i.key() - cropStart().frames(m_fps));
+            double y1 = br.bottom() - (i.value() - m_keyframeOffset) * maxh;
             if (qAbs(pos.x() - x1) < maxOffset && qAbs(pos.y() - y1) < 10) {
                 setToolTip('[' + QString::number((GenTime(i.key(), m_fps) - cropStart()).seconds(), 'f', 2) + i18n("seconds") + ", " + QString::number(i.value(), 'f', 1) + ']');
                 return i.key();
@@ -547,3 +545,5 @@ bool AbstractClipItem::isMainSelectedClip()
     return m_isMainSelectedClip;
 }
 
+
+#include "abstractclipitem.moc"
