@@ -27,7 +27,7 @@
 
 #include <QWheelEvent>
 
-ClipDurationDialog::ClipDurationDialog(AbstractClipItem *clip, Timecode tc, GenTime min, GenTime max, QWidget * parent):
+ClipDurationDialog::ClipDurationDialog(AbstractClipItem *clip, const Timecode &tc, const GenTime &min, const GenTime &max, QWidget * parent):
         QDialog(parent),
         m_clip(clip),
         m_min(min),
@@ -47,14 +47,14 @@ ClipDurationDialog::ClipDurationDialog(AbstractClipItem *clip, Timecode tc, GenT
     crop_end_box->addWidget(m_cropEnd);
 
     bool allowCrop = true;
-    if (clip->type() == AVWIDGET) {
+    if (clip->type() == AVWidget) {
         ClipItem *item = static_cast <ClipItem *>(clip);
-        int t = item->clipType();
-        if (t == COLOR || t == IMAGE || t == TEXT)
+        const int t = item->clipType();
+        if (t == Color || t == Image || t == Text)
             allowCrop = false;
     }
 
-    if (!allowCrop || clip->type() == TRANSITIONWIDGET) {
+    if (!allowCrop || clip->type() == TransitionWidget) {
         m_cropStart->setHidden(true);
         crop_label->hide();
         m_cropEnd->setHidden(true),
