@@ -60,11 +60,11 @@ ClipManager::ClipManager(KdenliveDoc *doc) :
     m_clipIdCounter = 1;
     m_folderIdCounter = 1;
     m_modifiedTimer.setInterval(1500);
-    connect(&m_fileWatcher, SIGNAL(dirty(const QString &)), this, SLOT(slotClipModified(const QString &)));
-    connect(&m_fileWatcher, SIGNAL(deleted(const QString &)), this, SLOT(slotClipMissing(const QString &)));
+    connect(&m_fileWatcher, SIGNAL(dirty(QString)), this, SLOT(slotClipModified(QString)));
+    connect(&m_fileWatcher, SIGNAL(deleted(QString)), this, SLOT(slotClipMissing(QString)));
 
     // Seems like a dirty signal is emitted anyways when a watched file is created, so don't react twice.
-    //connect(&m_fileWatcher, SIGNAL(created(const QString &)), this, SLOT(slotClipAvailable(const QString &)));
+    //connect(&m_fileWatcher, SIGNAL(created(QString)), this, SLOT(slotClipAvailable(QString)));
     connect(&m_modifiedTimer, SIGNAL(timeout()), this, SLOT(slotProcessModifiedClips()));
 
 #if KDE_IS_VERSION(4,5,0)
@@ -123,7 +123,7 @@ void ClipManager::clearCache()
 #endif
 }
 
-void ClipManager::slotRequestThumbs(const QString id, QList <int> frames)
+void ClipManager::slotRequestThumbs(const QString &id, const QList <int>& frames)
 {
     m_thumbsMutex.lock();
     foreach (int frame, frames) {
@@ -176,34 +176,34 @@ void ClipManager::slotGetThumbs()
         m_processingThumbId = i.key();
         QList<int> values = m_requestedThumbs.values(m_processingThumbId);
         m_requestedThumbs.remove(m_processingThumbId);
-	if (m_processingThumbId.startsWith("?")) {
-	    // if id starts with ?, it means the request comes from a clip property widget
-	    thumbType = 2;
-	    m_processingThumbId.remove(0, 1);
-	}
-	if (m_processingThumbId.startsWith("#")) {
-	    // if id starts with #, it means the request comes from project tree
-	    thumbType = 1;
-	    m_processingThumbId.remove(0, 1);
-	}
+        if (m_processingThumbId.startsWith("?")) {
+            // if id starts with ?, it means the request comes from a clip property widget
+            thumbType = 2;
+            m_processingThumbId.remove(0, 1);
+        }
+        if (m_processingThumbId.startsWith("#")) {
+            // if id starts with #, it means the request comes from project tree
+            thumbType = 1;
+            m_processingThumbId.remove(0, 1);
+        }
         m_thumbsMutex.unlock();
         qSort(values);
         DocClipBase *clip = getClipById(m_processingThumbId);
         if (!clip) continue;
         max = m_requestedThumbs.size() + values.count();
-	int pos;
+        int pos;
         while (!values.isEmpty() && clip->thumbProducer() && !m_abortThumb) {
-	    pos = values.takeFirst();
-	    switch (thumbType) {
-	      case 1:
-		  clip->thumbProducer()->getGenericThumb(pos, SubProjectItem::itemDefaultHeight(), thumbType);
-		  break;
-	      case 2:
-		  clip->thumbProducer()->getGenericThumb(pos, 180, thumbType);
-		  break;
-	      default:
-		  clip->thumbProducer()->getThumb(pos);
-	    }
+            pos = values.takeFirst();
+            switch (thumbType) {
+            case 1:
+                clip->thumbProducer()->getGenericThumb(pos, SubProjectItem::itemDefaultHeight(), thumbType);
+                break;
+            case 2:
+                clip->thumbProducer()->getGenericThumb(pos, 180, thumbType);
+                break;
+            default:
+                clip->thumbProducer()->getThumb(pos);
+            }
             done++;
             if (max > 3) emit displayMessage(i18n("Loading thumbnails"), 100 * done / max);
         }
@@ -227,7 +227,7 @@ void ClipManager::checkAudioThumbs()
     }
 
     m_thumbsMutex.lock();
-    for (int i = 0; i < m_clipList.count(); i++) {
+    for (int i = 0; i < m_clipList.count(); ++i) {
         DocClipBase *clip = m_clipList.at(i);
         if (clip->hasAudioThumb() && !clip->audioThumbCreated())
             m_audioThumbsQueue.append(m_clipList.at(i)->getId());
@@ -264,17 +264,17 @@ void ClipManager::slotGetAudioThumbs()
         if (hash.isEmpty()) continue;
         QString audioPath = projectFolder() + "/thumbs/" + hash + ".thumb";
         double lengthInFrames = clip->duration().frames(m_doc->fps());
-	int frequency = 0;
-	int channels = 0;
-	QString data = clip->getProperty("frequency");
-	if (!data.isEmpty()) frequency = data.toInt();
-	if (frequency <= 0) frequency = 48000;
-	data = clip->getProperty("channels");
-	if (!data.isEmpty()) channels = data.toInt();
-	if (channels <= 0) channels = 2;
-	int arrayWidth = 20;
+        int frequency = 0;
+        int channels = 0;
+        QString data = clip->getProperty("frequency");
+        if (!data.isEmpty()) frequency = data.toInt();
+        if (frequency <= 0) frequency = 48000;
+        data = clip->getProperty("channels");
+        if (!data.isEmpty()) channels = data.toInt();
+        if (channels <= 0) channels = 2;
+        int arrayWidth = 20;
         double frame = 0.0;
-	int maxVolume = 0;
+        int maxVolume = 0;
         audioByteArray storeIn;
         QFile f(audioPath);
         if (QFileInfo(audioPath).size() > 0 && f.open(QIODevice::ReadOnly)) {
@@ -294,9 +294,9 @@ void ClipManager::slotGetAudioThumbs()
                 h3 = 0;
                 for (int c = 0; c < channels; c++) {
                     QByteArray audioArray(arrayWidth, '\x00');
-                    for (int i = 0; i < arrayWidth; i++) {
+                    for (int i = 0; i < arrayWidth; ++i) {
                         audioArray[i] = channelarray.at(h2 + h3 + i);
-			if (audioArray.at(i) > maxVolume) maxVolume = audioArray.at(i);
+                        if (audioArray.at(i) > maxVolume) maxVolume = audioArray.at(i);
                     }
                     h3 += arrayWidth;
                     storeIn[z][c] = audioArray;
@@ -304,11 +304,11 @@ void ClipManager::slotGetAudioThumbs()
                 h2 += h1;
             }
             if (!m_abortAudioThumb) {
-		clip->setProperty("audio_max", QString::number(maxVolume - 64));
-		clip->updateAudioThumbnail(storeIn);
-	    }
+                clip->setProperty("audio_max", QString::number(maxVolume - 64));
+                clip->updateAudioThumbnail(storeIn);
+            }
             continue;
-        } 
+        }
         
         if (!f.open(QIODevice::WriteOnly)) {
             kDebug() << "++++++++  ERROR WRITING TO FILE: " << audioPath;
@@ -335,12 +335,11 @@ void ClipManager::slotGetAudioThumbs()
         }
 
         int last_val = 0;
-        int val = 0;
         double framesPerSecond = mlt_producer_get_fps(producer.get_producer());
         Mlt::Frame *mlt_frame;
 
         for (int z = (int) frame; z < (int)(frame + lengthInFrames) && producer.is_valid() &&  !m_abortAudioThumb; z++) {
-            val = (int)((z - frame) / (frame + lengthInFrames) * 100.0);
+            int val = (int)((z - frame) / (frame + lengthInFrames) * 100.0);
             if (last_val != val && val > 1) {
                 setThumbsProgress(i18n("Creating audio thumbnail for %1", url.fileName()), val);
                 last_val = val;
@@ -353,18 +352,18 @@ void ClipManager::slotGetAudioThumbs()
                 for (int c = 0; c < channels; c++) {
                     QByteArray audioArray;
                     audioArray.resize(arrayWidth);
-                    for (int i = 0; i < audioArray.size(); i++) {
-			double pcmval = *(pcm + c + i * samples / audioArray.size());
-			if (pcmval >= 0) {
-			    pcmval = sqrt(pcmval) / 2.83 + 64;
-			    audioArray[i] = pcmval;
-			    if (pcmval > maxVolume) maxVolume = pcmval;
-			}
-			else {
-			    pcmval = -sqrt(-pcmval) / 2.83 + 64;
-			    audioArray[i] = pcmval;
-			    if (-pcmval > maxVolume) maxVolume = -pcmval;
-			}
+                    for (int i = 0; i < audioArray.size(); ++i) {
+                        double pcmval = *(pcm + c + i * samples / audioArray.size());
+                        if (pcmval >= 0) {
+                            pcmval = sqrt(pcmval) / 2.83 + 64;
+                            audioArray[i] = pcmval;
+                            if (pcmval > maxVolume) maxVolume = pcmval;
+                        }
+                        else {
+                            pcmval = -sqrt(-pcmval) / 2.83 + 64;
+                            audioArray[i] = pcmval;
+                            if (-pcmval > maxVolume) maxVolume = -pcmval;
+                        }
                     }
                     f.write(audioArray);
                     storeIn[z][c] = audioArray;
@@ -380,7 +379,7 @@ void ClipManager::slotGetAudioThumbs()
             f.remove();
         } else {
             clip->updateAudioThumbnail(storeIn);
-	    clip->setProperty("audio_max", QString::number(maxVolume - 64));
+            clip->setProperty("audio_max", QString::number(maxVolume - 64));
         }
     }
     m_processingAudioThumbId.clear();
@@ -404,7 +403,7 @@ QMap <QString, QString> ClipManager::documentFolderList() const
 void ClipManager::addClip(DocClipBase *clip)
 {
     m_clipList.append(clip);
-    if (clip->clipType() != COLOR && clip->clipType() != SLIDESHOW  && !clip->fileURL().isEmpty()) {
+    if (clip->clipType() != Color && clip->clipType() != SlideShow  && !clip->fileURL().isEmpty()) {
         // listen for file change
         //kDebug() << "// LISTEN FOR: " << clip->fileURL().path();
         m_fileWatcher.addFile(clip->fileURL().path());
@@ -420,7 +419,7 @@ void ClipManager::slotDeleteClips(QStringList ids)
     QUndoCommand *delClips = new QUndoCommand();
     delClips->setText(i18np("Delete clip", "Delete clips", ids.size()));
 
-    for (int i = 0; i < ids.size(); i++) {
+    for (int i = 0; i < ids.size(); ++i) {
         DocClipBase *clip = getClipById(ids.at(i));
         if (clip) {
             new AddClipCommand(m_doc, clip->toXML(), ids.at(i), false, delClips);
@@ -431,10 +430,10 @@ void ClipManager::slotDeleteClips(QStringList ids)
 
 void ClipManager::deleteClip(const QString &clipId)
 {
-    for (int i = 0; i < m_clipList.count(); i++) {
+    for (int i = 0; i < m_clipList.count(); ++i) {
         if (m_clipList.at(i)->getId() == clipId) {
-	    DocClipBase *clip = m_clipList.takeAt(i);
-            if (clip->clipType() != COLOR && clip->clipType() != SLIDESHOW  && !clip->fileURL().isEmpty()) {
+            DocClipBase *clip = m_clipList.takeAt(i);
+            if (clip->clipType() != Color && clip->clipType() != SlideShow  && !clip->fileURL().isEmpty()) {
                 //if (m_clipList.at(i)->clipType() == IMAGE || m_clipList.at(i)->clipType() == AUDIO || (m_clipList.at(i)->clipType() == TEXT && !m_clipList.at(i)->fileURL().isEmpty())) {
                 // listen for file change
                 m_fileWatcher.removeFile(clip->fileURL().path());
@@ -455,7 +454,7 @@ DocClipBase *ClipManager::getClipById(QString clipId)
 {
     //kDebug() << "++++  CLIP MAN, LOOKING FOR CLIP ID: " << clipId;
     clipId = clipId.section('_', 0, 0);
-    for (int i = 0; i < m_clipList.count(); i++) {
+    for (int i = 0; i < m_clipList.count(); ++i) {
         if (m_clipList.at(i)->getId() == clipId) {
             //kDebug() << "++++  CLIP MAN, FOUND FOR CLIP ID: " << clipId;
             return m_clipList.at(i);
@@ -464,12 +463,12 @@ DocClipBase *ClipManager::getClipById(QString clipId)
     return NULL;
 }
 
-const QList <DocClipBase *> ClipManager::getClipByResource(QString resource)
+const QList <DocClipBase *> ClipManager::getClipByResource(const QString &resource)
 {
     QList <DocClipBase *> list;
     QString clipResource;
     QString proxyResource;
-    for (int i = 0; i < m_clipList.count(); i++) {
+    for (int i = 0; i < m_clipList.count(); ++i) {
         clipResource = m_clipList.at(i)->getProperty("resource");
         proxyResource = m_clipList.at(i)->getProperty("proxy");
         if (clipResource.isEmpty()) clipResource = m_clipList.at(i)->getProperty("colour");
@@ -483,14 +482,14 @@ const QList <DocClipBase *> ClipManager::getClipByResource(QString resource)
 
 void ClipManager::clearUnusedProducers()
 {
-    for (int i = 0; i < m_clipList.count(); i++) {
+    for (int i = 0; i < m_clipList.count(); ++i) {
         if (m_clipList.at(i)->numReferences() == 0) m_clipList.at(i)->deleteProducers();
     }
 }
 
 void ClipManager::resetProducersList(const QList <Mlt::Producer *> prods, bool displayRatioChanged, bool fpsChanged)
 {
-    for (int i = 0; i < m_clipList.count(); i++) {
+    for (int i = 0; i < m_clipList.count(); ++i) {
         if (m_clipList.at(i)->numReferences() > 0 || displayRatioChanged || fpsChanged) {
             m_clipList.at(i)->deleteProducers();
         }
@@ -498,7 +497,7 @@ void ClipManager::resetProducersList(const QList <Mlt::Producer *> prods, bool d
     QString id;
     Mlt::Producer *prod;
     QStringList brokenClips;
-    for (int i = 0; i < prods.count(); i++) {
+    for (int i = 0; i < prods.count(); ++i) {
         prod = prods.at(i);
         id = prod->get("id");
         if (id.contains('_')) id = id.section('_', 0, 0);
@@ -527,7 +526,7 @@ void ClipManager::slotAddClip(KIO::Job *job, const KUrl &, const KUrl &dst)
     slotAddClipList(KUrl::List () << dst, data);
 }
 
-void ClipManager::slotAddClipList(const KUrl::List urls, QMap <QString, QString> data)
+void ClipManager::slotAddClipList(const KUrl::List &urls, const QMap <QString, QString> &data)
 {
     QUndoCommand *addClips = new QUndoCommand();
     // Update list of removable volumes
@@ -540,23 +539,23 @@ void ClipManager::slotAddClipList(const KUrl::List urls, QMap <QString, QString>
                     continue;
             }
             if (isOnRemovableDevice(file)) {
-		int answer = KMessageBox::warningYesNoCancel(kapp->activeWindow(), i18n("Clip <b>%1</b><br /> is on a removable device, will not be available when device is unplugged", file.path()), i18n("File on a Removable Device"), KGuiItem(i18n("Copy file to project folder")), KGuiItem(i18n("Continue")), KStandardGuiItem::cancel(), QString("copyFilesToProjectFolder"));
-		if (answer == KMessageBox::Cancel) continue;
-		else if (answer == KMessageBox::Yes) {
-		    // Copy files to project folder
-		    QString sourcesFolder = m_doc->projectFolder().path(KUrl::AddTrailingSlash) + "clips/";
-		    KIO::NetAccess::mkdir(sourcesFolder, kapp->activeWindow());
-		    //KIO::filesize_t m_requestedSize;
-		    KIO::CopyJob *copyjob = KIO::copy (file, KUrl(sourcesFolder));
-		    //TODO: for some reason, passing metadata does not work...
-		    copyjob->addMetaData("group", data.value("group"));
-		    copyjob->addMetaData("groupId", data.value("groupId"));
-		    copyjob->addMetaData("comment", data.value("comment"));
-		    copyjob->ui()->setWindow(kapp->activeWindow());
-		    connect(copyjob, SIGNAL(copyingDone(KIO::Job *, const KUrl &, const KUrl &, time_t, bool, bool)), this, SLOT(slotAddClip(KIO::Job *, const KUrl &, const KUrl &)));
-		    continue;
-		}
-	    }
+                int answer = KMessageBox::warningYesNoCancel(kapp->activeWindow(), i18n("Clip <b>%1</b><br /> is on a removable device, will not be available when device is unplugged", file.path()), i18n("File on a Removable Device"), KGuiItem(i18n("Copy file to project folder")), KGuiItem(i18n("Continue")), KStandardGuiItem::cancel(), QString("copyFilesToProjectFolder"));
+                if (answer == KMessageBox::Cancel) continue;
+                else if (answer == KMessageBox::Yes) {
+                    // Copy files to project folder
+                    QString sourcesFolder = m_doc->projectFolder().path(KUrl::AddTrailingSlash) + "clips/";
+                    KIO::NetAccess::mkdir(sourcesFolder, kapp->activeWindow());
+                    //KIO::filesize_t m_requestedSize;
+                    KIO::CopyJob *copyjob = KIO::copy (file, KUrl(sourcesFolder));
+                    //TODO: for some reason, passing metadata does not work...
+                    copyjob->addMetaData("group", data.value("group"));
+                    copyjob->addMetaData("groupId", data.value("groupId"));
+                    copyjob->addMetaData("comment", data.value("comment"));
+                    copyjob->ui()->setWindow(kapp->activeWindow());
+                    connect(copyjob, SIGNAL(copyingDone(KIO::Job*,KUrl,KUrl,time_t,bool,bool)), this, SLOT(slotAddClip(KIO::Job*,KUrl,KUrl)));
+                    continue;
+                }
+            }
             kDebug() << "Adding clip: " << file.path();
             QDomDocument doc;
             QDomElement prod = doc.createElement("producer");
@@ -570,11 +569,11 @@ void ClipManager::slotAddClipList(const KUrl::List urls, QMap <QString, QString>
                 prod.setAttribute("groupid", data.value("groupId"));
             }
             if (data.contains("video_index")) prod.setAttribute("video_index", data.value("video_index"));
-	    if (data.contains("audio_index")) prod.setAttribute("audio_index", data.value("audio_index"));
-	    
+            if (data.contains("audio_index")) prod.setAttribute("audio_index", data.value("audio_index"));
+
             KMimeType::Ptr type = KMimeType::findByUrl(file);
             if (type->name().startsWith("image/")) {
-                prod.setAttribute("type", (int) IMAGE);
+                prod.setAttribute("type", (int) Image);
                 prod.setAttribute("in", 0);
                 prod.setAttribute("out", m_doc->getFramePos(KdenliveSettings::image_duration()) - 1);
                 if (KdenliveSettings::autoimagetransparency()) prod.setAttribute("transparency", 1);
@@ -583,12 +582,12 @@ void ClipManager::slotAddClipList(const KUrl::List urls, QMap <QString, QString>
                     KFileMetaInfo metaInfo(file.path(), QString("image/jpeg"), KFileMetaInfo::TechnicalInfo);
                     const QHash<QString, KFileMetaInfoItem> metaInfoItems = metaInfo.items();
                     foreach(const KFileMetaInfoItem & metaInfoItem, metaInfoItems) {
-			QDomElement meta = doc.createElement("metaproperty");
-			meta.setAttribute("name", "meta.attr." + metaInfoItem.name().section('#', 1));
-			QDomText value = doc.createTextNode(metaInfoItem.value().toString());
-			meta.setAttribute("tool", "KDE Metadata");
-			meta.appendChild(value);
-			prod.appendChild(meta);
+                        QDomElement meta = doc.createElement("metaproperty");
+                        meta.setAttribute("name", "meta.attr." + metaInfoItem.name().section('#', 1));
+                        QDomText value = doc.createTextNode(metaInfoItem.value().toString());
+                        meta.setAttribute("tool", "KDE Metadata");
+                        meta.appendChild(value);
+                        prod.appendChild(meta);
                     }
                 }
             } else if (type->is("application/x-kdenlivetitle")) {
@@ -597,10 +596,10 @@ void ClipManager::slotAddClipList(const KUrl::List urls, QMap <QString, QString>
                 QFile txtfile(file.path());
                 if (txtfile.open(QIODevice::ReadOnly) && txtdoc.setContent(&txtfile)) {
                     txtfile.close();
-                    prod.setAttribute("type", (int) TEXT);
+                    prod.setAttribute("type", (int) Text);
                     // extract embeded images
                     QDomNodeList items = txtdoc.elementsByTagName("content");
-                    for (int i = 0; i < items.count() ; i++) {
+                    for (int i = 0; i < items.count() ; ++i) {
                         QDomElement content = items.item(i).toElement();
                         if (content.hasAttribute("base64")) {
                             QString titlesFolder = m_doc->projectFolder().path(KUrl::AddTrailingSlash) + "titles/";
@@ -613,20 +612,20 @@ void ClipManager::slotAddClipList(const KUrl::List urls, QMap <QString, QString>
                     }
                     prod.setAttribute("transparency", 1);
                     prod.setAttribute("in", 0);
-		    if (!txtdoc.documentElement().hasAttribute("out")) {
-			prod.setAttribute("out", m_doc->getFramePos(KdenliveSettings::title_duration()) - 1);
-			txtdoc.documentElement().setAttribute("out", m_doc->getFramePos(KdenliveSettings::title_duration()) - 1);
-		    }
-		    else {
-			int out = txtdoc.documentElement().attribute("out").toInt();
-			if (out >= 0)
-			    prod.setAttribute("out", out);
-			else {
-			    prod.setAttribute("out", m_doc->getFramePos(KdenliveSettings::title_duration()) - 1);
-			    txtdoc.documentElement().setAttribute("out", m_doc->getFramePos(KdenliveSettings::title_duration()) - 1);
-			}
-		    }
-		    QString titleData = txtdoc.toString();
+                    if (!txtdoc.documentElement().hasAttribute("out")) {
+                        prod.setAttribute("out", m_doc->getFramePos(KdenliveSettings::title_duration()) - 1);
+                        txtdoc.documentElement().setAttribute("out", m_doc->getFramePos(KdenliveSettings::title_duration()) - 1);
+                    }
+                    else {
+                        int out = txtdoc.documentElement().attribute("out").toInt();
+                        if (out >= 0)
+                            prod.setAttribute("out", out);
+                        else {
+                            prod.setAttribute("out", m_doc->getFramePos(KdenliveSettings::title_duration()) - 1);
+                            txtdoc.documentElement().setAttribute("out", m_doc->getFramePos(KdenliveSettings::title_duration()) - 1);
+                        }
+                    }
+                    QString titleData = txtdoc.toString();
                     prod.setAttribute("xmldata", titleData);
                 } else
                     txtfile.close();
@@ -641,7 +640,7 @@ void ClipManager::slotAddClipList(const KUrl::List urls, QMap <QString, QString>
     }
 }
 
-void ClipManager::slotAddClipFile(const KUrl &url, QMap <QString, QString> data)
+void ClipManager::slotAddClipFile(const KUrl &url, const QMap <QString, QString> &data)
 {
     slotAddClipList(KUrl::List(url), data);
 }
@@ -651,7 +650,7 @@ void ClipManager::slotAddXmlClipFile(const QString &name, const QDomElement &xml
     QDomDocument doc;
     doc.appendChild(doc.importNode(xml, true));
     QDomElement prod = doc.documentElement();
-    prod.setAttribute("type", (int) PLAYLIST);
+    prod.setAttribute("type", (int) Playlist);
     uint id = m_clipIdCounter++;
     prod.setAttribute("id", QString::number(id));
     prod.setAttribute("name", name);
@@ -663,14 +662,14 @@ void ClipManager::slotAddXmlClipFile(const QString &name, const QDomElement &xml
     m_doc->commandStack()->push(command);
 }
 
-void ClipManager::slotAddColorClipFile(const QString &name, const QString &color, QString duration, const QString &group, const QString &groupId)
+void ClipManager::slotAddColorClipFile(const QString &name, const QString &color, const QString &duration, const QString &group, const QString &groupId)
 {
     QDomDocument doc;
     QDomElement prod = doc.createElement("producer");
     doc.appendChild(prod);
     prod.setAttribute("mlt_service", "colour");
     prod.setAttribute("colour", color);
-    prod.setAttribute("type", (int) COLOR);
+    prod.setAttribute("type", (int) Color);
     uint id = m_clipIdCounter++;
     prod.setAttribute("id", QString::number(id));
     prod.setAttribute("in", "0");
@@ -694,7 +693,7 @@ void ClipManager::slotAddSlideshowClipFile(QMap <QString, QString> properties, c
         prod.setAttribute(i.key(), i.value());
         ++i;
     }
-    prod.setAttribute("type", (int) SLIDESHOW);
+    prod.setAttribute("type", (int) SlideShow);
     uint id = m_clipIdCounter++;
     if (!group.isEmpty()) {
         prod.setAttribute("groupname", group);
@@ -720,7 +719,7 @@ void ClipManager::slotAddTextClipFile(const QString &titleName, int duration, co
         prod.setAttribute("groupname", group);
         prod.setAttribute("groupid", groupId);
     }
-    prod.setAttribute("type", (int) TEXT);
+    prod.setAttribute("type", (int) Text);
     prod.setAttribute("transparency", "1");
     prod.setAttribute("in", "0");
     prod.setAttribute("out", duration - 1);
@@ -741,7 +740,7 @@ void ClipManager::slotAddTextTemplateClip(QString titleName, const KUrl &path, c
         prod.setAttribute("groupname", group);
         prod.setAttribute("groupid", groupId);
     }
-    prod.setAttribute("type", (int) TEXT);
+    prod.setAttribute("type", (int) Text);
     prod.setAttribute("transparency", "1");
     prod.setAttribute("in", "0");
 
@@ -750,13 +749,13 @@ void ClipManager::slotAddTextTemplateClip(QString titleName, const KUrl &path, c
     QFile txtfile(path.path());
     if (txtfile.open(QIODevice::ReadOnly) && titledoc.setContent(&txtfile)) {
         txtfile.close();
-	if (titledoc.documentElement().hasAttribute("duration")) {
-	    duration = titledoc.documentElement().attribute("duration").toInt();
-	}
+        if (titledoc.documentElement().hasAttribute("duration")) {
+            duration = titledoc.documentElement().attribute("duration").toInt();
+        }
         else {
-	    // keep some time for backwards compatibility - 26/12/12
-	    duration = titledoc.documentElement().attribute("out").toInt();
-	}
+            // keep some time for backwards compatibility - 26/12/12
+            duration = titledoc.documentElement().attribute("out").toInt();
+        }
     } else txtfile.close();
 
     if (duration == 0) duration = m_doc->getFramePos(KdenliveSettings::title_duration());
@@ -813,20 +812,20 @@ QDomElement ClipManager::groupsXml() const
     QDomDocument doc;
     QDomElement groups = doc.createElement("groups");
     doc.appendChild(groups);
-    for (int i = 0; i < m_groupsList.count(); i++) {
+    for (int i = 0; i < m_groupsList.count(); ++i) {
         QDomElement group = doc.createElement("group");
         groups.appendChild(group);
         QList <QGraphicsItem *> children = m_groupsList.at(i)->childItems();
         for (int j = 0; j < children.count(); j++) {
-            if (children.at(j)->type() == AVWIDGET || children.at(j)->type() == TRANSITIONWIDGET) {
+            if (children.at(j)->type() == AVWidget || children.at(j)->type() == TransitionWidget) {
                 AbstractClipItem *item = static_cast <AbstractClipItem *>(children.at(j));
                 ItemInfo info = item->info();
-                if (item->type() == AVWIDGET) {
+                if (item->type() == AVWidget) {
                     QDomElement clip = doc.createElement("clipitem");
                     clip.setAttribute("track", info.track);
                     clip.setAttribute("position", info.startPos.frames(m_doc->fps()));
                     group.appendChild(clip);
-                } else if (item->type() == TRANSITIONWIDGET) {
+                } else if (item->type() == TransitionWidget) {
                     QDomElement clip = doc.createElement("transitionitem");
                     clip.setAttribute("track", info.track);
                     clip.setAttribute("position", info.startPos.frames(m_doc->fps()));
@@ -843,7 +842,7 @@ void ClipManager::slotClipModified(const QString &path)
 {
     //kDebug() << "// CLIP: " << path << " WAS MODIFIED";
     const QList <DocClipBase *> list = getClipByResource(path);
-    for (int i = 0; i < list.count(); i++) {
+    for (int i = 0; i < list.count(); ++i) {
         DocClipBase *clip = list.at(i);
         if (clip != NULL) {
             QString id = clip->getId();
@@ -875,7 +874,7 @@ void ClipManager::slotClipMissing(const QString &path)
 {
     // kDebug() << "// CLIP: " << path << " WAS MISSING";
     const QList <DocClipBase *> list = getClipByResource(path);
-    for (int i = 0; i < list.count(); i++) {
+    for (int i = 0; i < list.count(); ++i) {
         DocClipBase *clip = list.at(i);
         if (clip != NULL) emit missingClip(clip->getId());
     }
@@ -885,7 +884,7 @@ void ClipManager::slotClipAvailable(const QString &path)
 {
     // kDebug() << "// CLIP: " << path << " WAS ADDED";
     const QList <DocClipBase *> list = getClipByResource(path);
-    for (int i = 0; i < list.count(); i++) {
+    for (int i = 0; i < list.count(); ++i) {
         DocClipBase *clip = list.at(i);
         if (clip != NULL) emit availableClip(clip->getId());
     }
@@ -929,7 +928,7 @@ void ClipManager::listRemovableVolumes()
             continue;
 
         Solid::StorageDrive *drive = driveDevice.as<Solid::StorageDrive>();
-	if (!drive->isRemovable()) continue;
+        if (!drive->isRemovable()) continue;
 
         // check for StorageVolume
         Solid::Device volumeDevice;
@@ -960,7 +959,7 @@ void ClipManager::listRemovableVolumes()
 
 bool ClipManager::isOnRemovableDevice(const KUrl &url)
 {
-    SolidVolumeInfo volume;
+    //SolidVolumeInfo volume;
     QString path = url.path(KUrl::RemoveTrailingSlash);
     int volumeMatch = 0;
 
@@ -974,7 +973,7 @@ bool ClipManager::isOnRemovableDevice(const KUrl &url)
             if (length > volumeMatch)
             {
                 volumeMatch = v.path.length();
-                volume = v;
+                //volume = v;
             }
         }
     }
@@ -982,14 +981,16 @@ bool ClipManager::isOnRemovableDevice(const KUrl &url)
     return volumeMatch;
 }
 
-void ClipManager::projectTreeThumbReady(const QString &id, int frame, QImage img, int type)
+void ClipManager::projectTreeThumbReady(const QString &id, int frame, const QImage &img, int type)
 {
     switch (type) {
-      case 2:
-	  emit gotClipPropertyThumbnail(id, img);
-	  break;
-      default:
-	emit thumbReady(id, frame, img);
+    case 2:
+        emit gotClipPropertyThumbnail(id, img);
+        break;
+    default:
+        emit thumbReady(id, frame, img);
     }
 }
 
+
+#include "clipmanager.moc"
