@@ -33,12 +33,18 @@
 #include <KRun>
 
 #ifdef USE_NEPOMUK
-#if KDE_IS_VERSION(4,6,0)
-#include <Nepomuk/Variant>
-#include <Nepomuk/Resource>
-#include <Nepomuk/ResourceManager>
-#include <Nepomuk/Vocabulary/NIE>
+  #if KDE_IS_VERSION(4,6,0)
+    #include <Nepomuk/Variant>
+    #include <Nepomuk/Resource>
+    #include <Nepomuk/ResourceManager>
+    #include <Nepomuk/Vocabulary/NIE>
+  #endif
 #endif
+#ifdef USE_NEPOMUKCORE
+  #include <Nepomuk2/Variant>
+  #include <Nepomuk2/Resource>
+  #include <Nepomuk2/ResourceManager>
+  #include <Nepomuk2/Vocabulary/NIE>
 #endif
 
 
@@ -53,18 +59,17 @@ static const int SLIDETAB = 3;
 static const int IMAGETAB = 4;
 static const int MARKERTAB = 5;
 static const int METATAB = 6;
-static const int ADVANCEDTAB = 7;
 
 
-ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidget * parent) :
+ClipProperties::ClipProperties(DocClipBase *clip, const Timecode &tc, double fps, QWidget * parent) :
     QDialog(parent)
-    , m_clip(clip)
-    , m_tc(tc)
-    , m_fps(fps)
-    , m_count(0)
-    , m_clipNeedsRefresh(false)
-    , m_clipNeedsReLoad(false)
-    , m_proxyContainer(NULL)
+  , m_clip(clip)
+  , m_tc(tc)
+  , m_fps(fps)
+  , m_count(0)
+  , m_clipNeedsRefresh(false)
+  , m_clipNeedsReLoad(false)
+  , m_proxyContainer(NULL)
 {
     setAttribute(Qt::WA_DeleteOnClose, true);
     setFont(KGlobalSettings::toolBarFont());
@@ -85,7 +90,7 @@ ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidg
     
     // New display aspect ratio support
     if (props.contains("force_aspect_num") && props.value("force_aspect_num").toInt() > 0 &&
-        props.contains("force_aspect_den") && props.value("force_aspect_den").toInt() > 0) {
+            props.contains("force_aspect_den") && props.value("force_aspect_den").toInt() > 0) {
         m_view.clip_force_ar->setChecked(true);
         m_view.clip_ar_num->setEnabled(true);
         m_view.clip_ar_den->setEnabled(true);
@@ -200,37 +205,40 @@ ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidg
     QMap<QString, QStringList> meta = m_clip->metadata();
     QMap<QString, QStringList>::const_iterator i = meta.constBegin();
     while (i != meta.constEnd()) {
-	QStringList values = i.value();
-	QString parentName;
-	QString iconName;
-	if (values.count() > 1 && !values.at(1).isEmpty()) parentName = values.at(1);
-	else {
-	    if (KdenliveSettings::ffmpegpath().endsWith("avconv")) {
-		parentName = i18n("Libav");
-		iconName = "meta_libav.png";
-	    }
-	    else {
-		parentName = i18n("FFmpeg");
-		iconName = "meta_ffmpeg.png";
-	    }
-	}
-	QTreeWidgetItem *parent = NULL;
-	QList <QTreeWidgetItem *> matches = m_view.metadata_list->findItems(parentName, Qt::MatchExactly);
-	if (!matches.isEmpty()) parent = matches.at(0);
-	else {
-	    if (parentName == "Magic Lantern") iconName = "meta_magiclantern.png";
-	    parent = new QTreeWidgetItem(m_view.metadata_list, QStringList() << parentName);
-	    if (!iconName.isEmpty()) {
-		KIcon icon(KStandardDirs::locate("appdata", iconName));
-		parent->setIcon(0, icon);
-	    }
-	}
-	QTreeWidgetItem *metaitem = NULL;
+        QStringList values = i.value();
+        QString parentName;
+        QString iconName;
+        if (values.count() > 1 && !values.at(1).isEmpty()) {
+            parentName = values.at(1);
+        } else {
+            if (KdenliveSettings::ffmpegpath().endsWith("avconv")) {
+                parentName = i18n("Libav");
+                iconName = "meta_libav.png";
+            }
+            else {
+                parentName = i18n("FFmpeg");
+                iconName = "meta_ffmpeg.png";
+            }
+        }
+        QTreeWidgetItem *parent = NULL;
+        QList <QTreeWidgetItem *> matches = m_view.metadata_list->findItems(parentName, Qt::MatchExactly);
+        if (!matches.isEmpty()) {
+            parent = matches.at(0);
+        } else {
+            if (parentName == "Magic Lantern")
+                iconName = "meta_magiclantern.png";
+            parent = new QTreeWidgetItem(m_view.metadata_list, QStringList() << parentName);
+            if (!iconName.isEmpty()) {
+                KIcon icon(KStandardDirs::locate("appdata", iconName));
+                parent->setIcon(0, icon);
+            }
+        }
+        QTreeWidgetItem *metaitem = NULL;
         if (parent) {
-	    metaitem = new QTreeWidgetItem(parent);
-	    parent->setExpanded(true);
-	}
-	else metaitem = new QTreeWidgetItem(m_view.metadata_list);
+            metaitem = new QTreeWidgetItem(parent);
+            parent->setExpanded(true);
+        }
+        else metaitem = new QTreeWidgetItem(m_view.metadata_list);
         metaitem->setText(0, i.key()); //i18n(i.key().section('.', 2, 3).toUtf8().data()));
         metaitem->setText(1, values.at(0));
         ++i;
@@ -256,7 +264,7 @@ ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidg
         new QTreeWidgetItem(m_view.clip_aproperties, QStringList() << i18n("Frequency") << props.value("frequency"));
     
 
-    CLIPTYPE t = m_clip->clipType();
+    ClipType t = m_clip->clipType();
     
     if (props.contains("proxy") && props.value("proxy") != "-") {
         KFileItem f(KFileItem::Unknown, KFileItem::Unknown, KUrl(props.value("proxy")), true);
@@ -272,11 +280,11 @@ ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidg
         l->addWidget(pb);
         connect(pb, SIGNAL(clicked()), this, SLOT(slotDeleteProxy()));
         m_proxyContainer->setLayout(l);
-        if (t == IMAGE) {
+        if (t == Image) {
             m_view.tab_image->layout()->addWidget(line);
             m_view.tab_image->layout()->addWidget(m_proxyContainer);
         }
-        else if (t == AUDIO) {
+        else if (t == Audio) {
             m_view.tab_audio->layout()->addWidget(line);
             m_view.tab_audio->layout()->addWidget(m_proxyContainer);
         }
@@ -286,18 +294,18 @@ ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidg
         }
     }
     
-    if (t != AUDIO && t != AV) {
+    if (t != Audio && t != AV) {
         m_view.clip_force_aindex->setEnabled(false);
     }
 
-    if (t != VIDEO && t != AV) {
+    if (t != Video && t != AV) {
         m_view.clip_force_vindex->setEnabled(false);
     }
 
-    if (t == PLAYLIST)
-	m_view.tabWidget->setTabText(VIDEOTAB, i18n("Playlist"));
+    if (t == Playlist)
+        m_view.tabWidget->setTabText(VIDEOTAB, i18n("Playlist"));
 
-    if (t == IMAGE) {
+    if (t == Image) {
         m_view.tabWidget->removeTab(SLIDETAB);
         m_view.tabWidget->removeTab(COLORTAB);
         m_view.tabWidget->removeTab(AUDIOTAB);
@@ -308,9 +316,10 @@ ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidg
             m_view.image_transparency->setChecked(props.value("transparency").toInt());
         connect(m_view.image_transparency, SIGNAL(toggled(bool)), this, SLOT(slotModified()));
         int width = 180.0 * KdenliveSettings::project_display_ratio();
-        if (width % 2 == 1) width++;
+        if (width % 2 == 1)
+            width++;
         m_view.clip_thumb->setPixmap(QPixmap(url.path()).scaled(QSize(width, 180), Qt::KeepAspectRatio));
-    } else if (t == COLOR) {
+    } else if (t == Color) {
         m_view.clip_path->setEnabled(false);
         m_view.tabWidget->removeTab(METATAB);
         m_view.tabWidget->removeTab(IMAGETAB);
@@ -320,8 +329,8 @@ ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidg
         m_view.clip_thumb->setHidden(true);
         m_view.clip_color->setColor(QColor('#' + props.value("colour").right(8).left(6)));
         connect(m_view.clip_color, SIGNAL(changed(QColor)), this, SLOT(slotModified()));
-    } else if (t == SLIDESHOW) {
-        if (url.fileName().startsWith(".all.")) {
+    } else if (t == SlideShow) {
+        if (url.fileName().startsWith(QLatin1String(".all."))) {
             // the image sequence is defined by mimetype
             m_view.clip_path->setText(url.directory());
         } else {
@@ -365,7 +374,7 @@ ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidg
             m_view.animation->setCurrentIndex(0);
         QString path = props.value("resource");
         QString ext = path.section('.', -1);
-        for (int i = 0; i < m_view.image_type->count(); i++) {
+        for (int i = 0; i < m_view.image_type->count(); ++i) {
             if (m_view.image_type->itemData(i).toString() == ext) {
                 m_view.image_type->setCurrentIndex(i);
                 break;
@@ -431,7 +440,7 @@ ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidg
         connect(m_view.slide_luma, SIGNAL(stateChanged(int)), this, SLOT(slotEnableLumaFile(int)));
         connect(m_view.image_type, SIGNAL(currentIndexChanged(int)), this, SLOT(parseFolder()));
 
-    } else if (t != AUDIO) {
+    } else if (t != Audio) {
         m_view.tabWidget->removeTab(IMAGETAB);
         m_view.tabWidget->removeTab(SLIDETAB);
         m_view.tabWidget->removeTab(COLORTAB);
@@ -442,11 +451,12 @@ ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidg
         m_view.clip_aproperties->setItemDelegate(del2);
         m_view.clip_aproperties->setStyleSheet(QString("QTreeWidget { background-color: transparent;}"));
         m_view.clip_vproperties->setStyleSheet(QString("QTreeWidget { background-color: transparent;}"));
-	loadVideoProperties(props);      
+        loadVideoProperties(props);
         
-	m_view.clip_thumb->setMinimumSize(180 * KdenliveSettings::project_display_ratio(), 180);
+        m_view.clip_thumb->setMinimumSize(180 * KdenliveSettings::project_display_ratio(), 180);
         
-        if (t == IMAGE || t == VIDEO || t == PLAYLIST) m_view.tabWidget->removeTab(AUDIOTAB);
+        if (t == Image || t == Video || t == Playlist)
+            m_view.tabWidget->removeTab(AUDIOTAB);
     } else {
         m_view.tabWidget->removeTab(IMAGETAB);
         m_view.tabWidget->removeTab(SLIDETAB);
@@ -455,7 +465,7 @@ ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidg
         m_view.clip_thumb->setHidden(true);
     }
 
-    if (t != SLIDESHOW && t != COLOR) {
+    if (t != SlideShow && t != Color) {
         KFileItem f(KFileItem::Unknown, KFileItem::Unknown, url, true);
         m_view.clip_filesize->setText(KIO::convertSize(f.size()));
     } else {
@@ -464,8 +474,9 @@ ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidg
     }
     m_view.clip_duration->setInputMask(tc.mask());
     m_view.clip_duration->setText(tc.getTimecode(m_clip->duration()));
-    if (t != IMAGE && t != COLOR && t != TEXT) m_view.clip_duration->setReadOnly(true);
-    else {
+    if (t != Image && t != Color && t != Text) {
+        m_view.clip_duration->setReadOnly(true);
+    } else {
         connect(m_view.clip_duration, SIGNAL(editingFinished()), this, SLOT(slotCheckMaxLength()));
         connect(m_view.clip_duration, SIGNAL(textChanged(QString)), this, SLOT(slotModified()));
     }
@@ -488,9 +499,9 @@ ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidg
     m_view.analysis_save->setIcon(KIcon("document-save-as"));
     m_view.analysis_save->setToolTip(i18n("Save analysis data"));
 
-        // Check for Nepomuk metadata
+    // Check for Nepomuk metadata
 #ifdef USE_NEPOMUK
-#if KDE_IS_VERSION(4,6,0)
+  #if KDE_IS_VERSION(4,6,0)
     if (!url.isEmpty()) {
         Nepomuk::ResourceManager::instance()->init();
         Nepomuk::Resource res( url.path() );
@@ -500,19 +511,38 @@ ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidg
             m_view.clip_license->setText(i18n("License: %1", res.property(Nepomuk::Vocabulary::NIE::license()).toString()));
             if (ltype.startsWith("http")) {
                 m_view.clip_license->setUrl(ltype);
-                connect(m_view.clip_license, SIGNAL(leftClickedUrl(const QString &)), this, SLOT(slotOpenUrl(const QString &)));
+                connect(m_view.clip_license, SIGNAL(leftClickedUrl(QString)), this, SLOT(slotOpenUrl(QString)));
             }
         }
         else m_view.clip_license->setHidden(true);
     }
     else m_view.clip_license->setHidden(true);
-#else
+  #else
     m_view.clip_license->setHidden(true);
-#endif
+  #endif
 #else
+  #ifdef USE_NEPOMUKCORE
+
+    if (!url.isEmpty()) {
+        Nepomuk2::ResourceManager::instance()->init();
+        Nepomuk2::Resource res( url.path() );
+        // Check if file has a license
+        if (res.hasProperty(Nepomuk2::Vocabulary::NIE::license())) {
+            QString ltype = res.property(Nepomuk2::Vocabulary::NIE::licenseType()).toString();
+            m_view.clip_license->setText(i18n("License: %1", res.property(Nepomuk2::Vocabulary::NIE::license()).toString()));
+            if (ltype.startsWith("http")) {
+                m_view.clip_license->setUrl(ltype);
+                connect(m_view.clip_license, SIGNAL(leftClickedUrl(QString)), this, SLOT(slotOpenUrl(QString)));
+            }
+        }
+        else m_view.clip_license->setHidden(true);
+    }
+    else m_view.clip_license->setHidden(true);
+  #else
     m_view.clip_license->setHidden(true);
+  #endif
 #endif
-    
+
     slotFillMarkersList(m_clip);
     slotUpdateAnalysisData(m_clip);
     
@@ -521,7 +551,7 @@ ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidg
     connect(m_view.marker_delete, SIGNAL(clicked()), this, SLOT(slotDeleteMarker()));
     connect(m_view.marker_save, SIGNAL(clicked()), this, SLOT(slotSaveMarkers()));
     connect(m_view.marker_load, SIGNAL(clicked()), this, SLOT(slotLoadMarkers()));
-    connect(m_view.markers_list, SIGNAL(doubleClicked(const QModelIndex &)), this, SLOT(slotEditMarker()));
+    connect(m_view.markers_list, SIGNAL(doubleClicked(QModelIndex)), this, SLOT(slotEditMarker()));
     
     connect(m_view.analysis_delete, SIGNAL(clicked()), this, SLOT(slotDeleteAnalysis()));
     connect(m_view.analysis_save, SIGNAL(clicked()), this, SLOT(slotSaveAnalysis()));
@@ -539,7 +569,7 @@ ClipProperties::ClipProperties(DocClipBase *clip, Timecode tc, double fps, QWidg
 
 
 // Used for multiple clips editing
-ClipProperties::ClipProperties(QList <DocClipBase *>cliplist, Timecode tc, QMap <QString, QString> commonproperties, QWidget * parent) :
+ClipProperties::ClipProperties(const QList <DocClipBase *> &cliplist, const Timecode &tc, const QMap <QString, QString> &commonproperties, QWidget * parent) :
     QDialog(parent),
     m_clip(NULL),
     m_tc(tc),
@@ -673,7 +703,9 @@ ClipProperties::ClipProperties(QList <DocClipBase *>cliplist, Timecode tc, QMap
         if (commonproperties.value("out").toInt() > 0) {
             m_view.clip_force_out->setChecked(true);
             m_view.clip_out->setText(m_tc.getTimecodeFromFrames(commonproperties.value("out").toInt()));
-        } else m_view.clip_out->setText(KdenliveSettings::image_duration());
+        } else {
+            m_view.clip_out->setText(KdenliveSettings::image_duration());
+        }
     } else {
         m_view.clip_force_out->setHidden(true);
         m_view.clip_out->setHidden(true);
@@ -683,47 +715,48 @@ ClipProperties::ClipProperties(QList <DocClipBase *>cliplist, Timecode tc, QMap
 ClipProperties::~ClipProperties()
 {
     QAbstractItemDelegate *del1 = m_view.clip_vproperties->itemDelegate();
-    if (del1) delete del1;
+    delete del1;
     QAbstractItemDelegate *del2 = m_view.clip_aproperties->itemDelegate();
-    if (del2) delete del2;
+    delete del2;
 }
 
 
-void ClipProperties::loadVideoProperties(QMap <QString, QString> props)
+void ClipProperties::loadVideoProperties(const QMap <QString, QString> &props)
 {
     m_view.clip_vproperties->clear();
     if (props.contains("videocodec"))
-	new QTreeWidgetItem(m_view.clip_vproperties, QStringList() << i18n("Video codec") << props.value("videocodec"));
+        new QTreeWidgetItem(m_view.clip_vproperties, QStringList() << i18n("Video codec") << props.value("videocodec"));
     else if (props.contains("videocodecid"))
-	new QTreeWidgetItem(m_view.clip_vproperties, QStringList() << i18n("Video codec") << props.value("videocodecid"));
+        new QTreeWidgetItem(m_view.clip_vproperties, QStringList() << i18n("Video codec") << props.value("videocodecid"));
 
     if (props.contains("frame_size"))
-	new QTreeWidgetItem(m_view.clip_vproperties, QStringList() << i18n("Frame size") << props.value("frame_size"));
+        new QTreeWidgetItem(m_view.clip_vproperties, QStringList() << i18n("Frame size") << props.value("frame_size"));
 
     if (props.contains("fps")) {
-	new QTreeWidgetItem(m_view.clip_vproperties, QStringList() << i18n("Frame rate") << props.value("fps"));
+        new QTreeWidgetItem(m_view.clip_vproperties, QStringList() << i18n("Frame rate") << props.value("fps"));
         if (!m_view.clip_framerate->isEnabled()) m_view.clip_framerate->setValue(props.value("fps").toDouble());
     }
 
     if (props.contains("progressive")) {
-	int scanning = props.value("progressive").toInt();
+        int scanning = props.value("progressive").toInt();
         QString txt = scanning == 1 ? i18n("Progressive") : i18n("Interlaced");
         new QTreeWidgetItem(m_view.clip_vproperties, QStringList() << i18n("Scanning") << txt);
     }
-        
+
     if (props.contains("aspect_ratio"))
-	new QTreeWidgetItem(m_view.clip_vproperties, QStringList() << i18n("Pixel aspect ratio") << props.value("aspect_ratio"));
+        new QTreeWidgetItem(m_view.clip_vproperties, QStringList() << i18n("Pixel aspect ratio") << props.value("aspect_ratio"));
 
     if (props.contains("pix_fmt"))
-	new QTreeWidgetItem(m_view.clip_vproperties, QStringList() << i18n("Pixel format") << props.value("pix_fmt"));
+        new QTreeWidgetItem(m_view.clip_vproperties, QStringList() << i18n("Pixel format") << props.value("pix_fmt"));
 
     if (props.contains("colorspace"))
-	new QTreeWidgetItem(m_view.clip_vproperties, QStringList() << i18n("Colorspace") << ProfilesDialog::getColorspaceDescription(props.value("colorspace").toInt()));
+        new QTreeWidgetItem(m_view.clip_vproperties, QStringList() << i18n("Colorspace") << ProfilesDialog::getColorspaceDescription(props.value("colorspace").toInt()));
 }
 
-void ClipProperties::slotGotThumbnail(const QString &id, QImage img)
+void ClipProperties::slotGotThumbnail(const QString &id, const QImage &img)
 {
-    if (id != m_clip->getId()) return;
+    if (id != m_clip->getId())
+        return;
     QPixmap framedPix(img.width(), img.height());
     framedPix.fill(Qt::transparent);
     QPainter p(&framedPix);
@@ -741,21 +774,24 @@ void ClipProperties::slotApplyProperties()
     if (m_clip != NULL) {
         QMap <QString, QString> props = properties();
         emit applyNewClipProperties(m_clip->getId(), m_clip->currentProperties(props), props, needsTimelineRefresh(), needsTimelineReload());
-	QTimer::singleShot(1000, this, SLOT(slotReloadVideoProperties()));
-	if (props.contains("force_aspect_num")) QTimer::singleShot(1000, this, SLOT(slotReloadVideoThumb()));
+        QTimer::singleShot(1000, this, SLOT(slotReloadVideoProperties()));
+        if (props.contains("force_aspect_num"))
+            QTimer::singleShot(1000, this, SLOT(slotReloadVideoThumb()));
     }
     m_view.buttonBox->button(QDialogButtonBox::Apply)->setEnabled(false);
 }
 
 void ClipProperties::slotReloadVideoProperties()
 {
-    if (m_clip == NULL) return;
+    if (m_clip == NULL)
+        return;
     loadVideoProperties(m_clip->properties());
 }
 
 void ClipProperties::slotReloadVideoThumb()
 {
-    if (m_clip == NULL) return;
+    if (m_clip == NULL)
+        return;
     emit requestThumb(QString('?' + m_clip->getId()), QList<int>() << m_clip->getClipThumbFrame());
 }
 
@@ -806,10 +842,10 @@ void ClipProperties::slotUpdateAnalysisData(DocClipBase *clip)
     m_view.analysis_box->setHidden(analysis.isEmpty());
     QMap<QString, QString>::const_iterator i = analysis.constBegin();
     while (i != analysis.constEnd()) {
-	QStringList itemtext;
-	itemtext << i.key() << i.value();
-	(void) new QTreeWidgetItem(m_view.analysis_list, itemtext);
-	++i;
+        QStringList itemtext;
+        itemtext << i.key() << i.value();
+        (void) new QTreeWidgetItem(m_view.analysis_list, itemtext);
+        ++i;
     }
 }
 
@@ -823,7 +859,7 @@ void ClipProperties::slotFillMarkersList(DocClipBase *clip)
         QStringList itemtext;
         itemtext << time << marks.at(count).comment();
         QTreeWidgetItem *item = new QTreeWidgetItem(m_view.markers_list, itemtext);
-	item->setData(0, Qt::DecorationRole, CommentedTime::markerColor(marks.at(count).markerType()));
+        item->setData(0, Qt::DecorationRole, CommentedTime::markerColor(marks.at(count).markerType()));
     }
 }
 
@@ -831,10 +867,10 @@ void ClipProperties::slotAddMarker()
 {
     CommentedTime marker(GenTime(), i18n("Marker"));
     QPointer<MarkerDialog> d = new MarkerDialog(m_clip, marker,
-                                          m_tc, i18n("Add Marker"), this);
+                                                m_tc, i18n("Add Marker"), this);
     if (d->exec() == QDialog::Accepted) {
-	QList <CommentedTime> markers;
-	markers << d->newMarker();
+        QList <CommentedTime> markers;
+        markers << d->newMarker();
         emit addMarkers(m_clip->getId(), markers);
     }
     delete d;
@@ -857,8 +893,8 @@ void ClipProperties::slotEditMarker()
     if (pos < 0 || pos > marks.count() - 1) return;
     MarkerDialog d(m_clip, marks.at(pos), m_tc, i18n("Edit Marker"), this);
     if (d.exec() == QDialog::Accepted) {
-	QList <CommentedTime> markers;
-	markers << d.newMarker();
+        QList <CommentedTime> markers;
+        markers << d.newMarker();
         emit addMarkers(m_clip->getId(), markers);
     }
 }
@@ -867,12 +903,12 @@ void ClipProperties::slotDeleteMarker()
 {
     QList < CommentedTime > marks = m_clip->commentedSnapMarkers();
     QList < CommentedTime > toDelete;
-    for (int i = 0; i < marks.count(); i++) {
-	if (m_view.markers_list->topLevelItem(i)->isSelected()) {
-	    CommentedTime marker = marks.at(i);
-	    marker.setMarkerType(-1);
-	    toDelete << marker;
-	}
+    for (int i = 0; i < marks.count(); ++i) {
+        if (m_view.markers_list->topLevelItem(i)->isSelected()) {
+            CommentedTime marker = marks.at(i);
+            marker.setMarkerType(-1);
+            toDelete << marker;
+        }
     }
     emit addMarkers(m_clip->getId(), toDelete);
 }
@@ -885,8 +921,9 @@ void ClipProperties::slotDeleteAnalysis()
 
 void ClipProperties::slotSaveAnalysis()
 {
-    QString url = KFileDialog::getSaveFileName(KUrl("kfiledialog:///projectfolder"), "text/plain", this, i18n("Save Analysis Data"));
-    if (url.isEmpty()) return;
+    const QString url = KFileDialog::getSaveFileName(KUrl("kfiledialog:///projectfolder"), "text/plain", this, i18n("Save Analysis Data"));
+    if (url.isEmpty())
+        return;
     KSharedConfigPtr config = KSharedConfig::openConfig(url, KConfig::SimpleConfig);
     KConfigGroup analysisConfig(config, "Analysis");
     QTreeWidgetItem *current = m_view.analysis_list->currentItem();
@@ -895,16 +932,17 @@ void ClipProperties::slotSaveAnalysis()
 
 void ClipProperties::slotLoadAnalysis()
 {
-    QString url = KFileDialog::getOpenFileName(KUrl("kfiledialog:///projectfolder"), "text/plain", this, i18n("Open Analysis Data"));
-    if (url.isEmpty()) return;
+    const QString url = KFileDialog::getOpenFileName(KUrl("kfiledialog:///projectfolder"), "text/plain", this, i18n("Open Analysis Data"));
+    if (url.isEmpty())
+        return;
     KSharedConfigPtr config = KSharedConfig::openConfig(url, KConfig::SimpleConfig);
     KConfigGroup transConfig(config, "Analysis");
     // read the entries
     QMap< QString, QString > profiles = transConfig.entryMap();
     QMapIterator<QString, QString> i(profiles);
     while (i.hasNext()) {
-	i.next();
-	emit editAnalysis(m_clip->getId(), i.key(), i.value());
+        i.next();
+        emit editAnalysis(m_clip->getId(), i.key(), i.value());
     }
 }
 
@@ -913,12 +951,12 @@ const QString &ClipProperties::clipId() const
     return m_clip->getId();
 }
 
-
 QMap <QString, QString> ClipProperties::properties()
 {
     QMap <QString, QString> props;
     QLocale locale;
-    CLIPTYPE t = UNKNOWN;
+    locale.setNumberOptions(QLocale::OmitGroupSeparator);
+    ClipType t = Unknown;
     if (m_clip != NULL) {
         t = m_clip->clipType();
         m_old_props = m_clip->properties();
@@ -928,7 +966,7 @@ QMap <QString, QString> ClipProperties::properties()
     int aspectDenominator = m_view.clip_ar_den->value();
     if (m_view.clip_force_ar->isChecked()) {
         if (aspectNumerator != m_old_props.value("force_aspect_num").toInt() ||
-            aspectDenominator != m_old_props.value("force_aspect_den").toInt()) {
+                aspectDenominator != m_old_props.value("force_aspect_den").toInt()) {
             props["force_aspect_num"] = QString::number(aspectNumerator);
             props["force_aspect_den"] = QString::number(aspectDenominator);
             props["force_aspect_ratio"].clear();
@@ -1039,7 +1077,7 @@ QMap <QString, QString> ClipProperties::properties()
     if (m_old_props.value("description") != m_view.clip_description->text())
         props["description"] = m_view.clip_description->text();
 
-    if (t == COLOR) {
+    if (t == Color) {
         QString new_color = m_view.clip_color->color().name();
         if (new_color != QString('#' + m_old_props.value("colour").right(8).left(6))) {
             m_clipNeedsRefresh = true;
@@ -1049,7 +1087,7 @@ QMap <QString, QString> ClipProperties::properties()
         if (duration != m_clip->duration().frames(m_fps)) {
             props["out"] = QString::number(duration - 1);
         }
-    } else if (t == IMAGE) {
+    } else if (t == Image) {
         if ((int) m_view.image_transparency->isChecked() != m_old_props.value("transparency").toInt()) {
             props["transparency"] = QString::number((int)m_view.image_transparency->isChecked());
             //m_clipNeedsRefresh = true;
@@ -1058,7 +1096,7 @@ QMap <QString, QString> ClipProperties::properties()
         if (duration != m_clip->duration().frames(m_fps)) {
             props["out"] = QString::number(duration - 1);
         }
-    } else if (t == SLIDESHOW) {
+    } else if (t == SlideShow) {
         QString value = QString::number((int) m_view.slide_loop->isChecked());
         if (m_old_props.value("loop") != value) props["loop"] = value;
         value = QString::number((int) m_view.slide_crop->isChecked());
@@ -1160,31 +1198,31 @@ void ClipProperties::parseFolder(bool reloadThumb)
     QStringList result = dir.entryList(QDir::Files);
 
     if (!isMime) {
-	int offset = 0;
-	QString path = m_view.clip_path->text();
-	if (path.contains('?')) {
-	    // New MLT syntax
-	    offset = m_view.clip_path->text().section(':', -1).toInt();
-	    path = path.section('?', 0, 0);
-	}
-	QString filter = KUrl(path).fileName();
-	QString ext = filter.section('.', -1);
-	filter = filter.section('%', 0, -2);
-	QString regexp = '^' + filter + "\\d+\\." + ext + '$';
-	QRegExp rx(regexp);
-	QStringList entries;
-	int ix;
-	foreach(const QString & path, result) {
-	    if (rx.exactMatch(path)) {
-		if (offset > 0) {
-		    // make sure our image is in the range we want (> begin)
-		    ix = path.section(filter, 1).section('.', 0, 0).toInt();
-		    if (ix < offset) continue;
-		}
-		entries << path;
-	    }
-	}
-	result = entries;
+        int offset = 0;
+        QString path = m_view.clip_path->text();
+        if (path.contains('?')) {
+            // New MLT syntax
+            offset = m_view.clip_path->text().section(':', -1).toInt();
+            path = path.section('?', 0, 0);
+        }
+        QString filter = KUrl(path).fileName();
+        QString ext = filter.section('.', -1);
+        filter = filter.section('%', 0, -2);
+        QString regexp = '^' + filter + "\\d+\\." + ext + '$';
+        QRegExp rx(regexp);
+        QStringList entries;
+        int ix;
+        foreach(const QString & path, result) {
+            if (rx.exactMatch(path)) {
+                if (offset > 0) {
+                    // make sure our image is in the range we want (> begin)
+                    ix = path.section(filter, 1).section('.', 0, 0).toInt();
+                    if (ix < offset) continue;
+                }
+                entries << path;
+            }
+        }
+        result = entries;
     }
 
     m_count = result.count();
@@ -1200,19 +1238,20 @@ void ClipProperties::parseFolder(bool reloadThumb)
     QMap <QString, QString> props = m_clip->properties();
     m_view.clip_duration->setText(m_tc.getTimecodeFromFrames(props.value("ttl").toInt() * m_count));
     if (reloadThumb) {
-	int width = 180.0 * KdenliveSettings::project_display_ratio();
-	if (width % 2 == 1) width++;
-	QString filePath = m_view.clip_path->text();
-	if (isMime) filePath.append(extension);
-	QPixmap pix = m_clip->thumbProducer()->getImage(KUrl(filePath), 1, width, 180);
-	m_view.clip_thumb->setPixmap(pix);
+        int width = 180.0 * KdenliveSettings::project_display_ratio();
+        if (width % 2 == 1) width++;
+        QString filePath = m_view.clip_path->text();
+        if (isMime) filePath.append(extension);
+        QPixmap pix = m_clip->thumbProducer()->getImage(KUrl(filePath), 1, width, 180);
+        m_view.clip_thumb->setPixmap(pix);
     }
 }
 
 void ClipProperties::slotCheckMaxLength()
 {
-    if (m_clip->maxDuration() == GenTime()) return;
-    int duration = m_tc.getFrameCount(m_view.clip_duration->text());
+    if (m_clip->maxDuration() == GenTime())
+        return;
+    const int duration = m_tc.getFrameCount(m_view.clip_duration->text());
     if (duration > m_clip->maxDuration().frames(m_fps)) {
         m_view.clip_duration->setText(m_tc.getTimecode(m_clip->maxDuration()));
     }
@@ -1220,7 +1259,7 @@ void ClipProperties::slotCheckMaxLength()
 
 void ClipProperties::slotUpdateDurationFormat(int ix)
 {
-    bool framesFormat = ix == 1;
+    bool framesFormat = (ix == 1);
     if (framesFormat) {
         // switching to frames count, update widget
         m_view.slide_duration_frames->setValue(m_tc.getFrameCount(m_view.slide_duration->text()));
@@ -1242,10 +1281,11 @@ void ClipProperties::slotUpdateDurationFormat(int ix)
 
 void ClipProperties::slotDeleteProxy()
 {
-      QString proxy = m_clip->getProperty("proxy");
-      if (proxy.isEmpty()) return;
-      emit deleteProxy(proxy);
-      if (m_proxyContainer) delete m_proxyContainer;
+    const QString proxy = m_clip->getProperty("proxy");
+    if (proxy.isEmpty())
+        return;
+    emit deleteProxy(proxy);
+    delete m_proxyContainer;
 }
 
 void ClipProperties::slotOpenUrl(const QString &url)
