@@ -55,11 +55,11 @@ public:
     virtual void mouseReleaseEvent(QMouseEvent * event);
     virtual void mouseMoveEvent(QMouseEvent * event);
     virtual void mouseDoubleClickEvent(QMouseEvent *event);
-    void addTrack(TrackInfo type, int ix = -1);
+    void addTrack(const TrackInfo &type, int ix = -1);
     void removeTrack(int ix);
     /** @brief Makes the document use new track infos (name, type, ...). */
-    void configTracks(QList <TrackInfo> trackInfos);
-    int cursorPos();
+    void configTracks(const QList<TrackInfo> &trackInfos);
+    int cursorPos() const;
     void checkAutoScroll();
     /**
       Move the clip at \c start to \c end.
@@ -68,7 +68,7 @@ public:
       For example, attempting to move a clip to t = -1 s will actually move it to t = 0 s.
       */
     bool moveClip(const ItemInfo &start, const ItemInfo &end, bool refresh, ItemInfo *out_actualEnd = NULL);
-    void moveGroup(QList <ItemInfo> startClip, QList <ItemInfo> startTransition, const GenTime &offset, const int trackOffset, bool reverseMove = false);
+    void moveGroup(QList<ItemInfo> startClip, QList<ItemInfo> startTransition, const GenTime &offset, const int trackOffset, bool reverseMove = false);
     /** move transition, startPos = (old start, old end), endPos = (new start, new end) */
     void moveTransition(const ItemInfo &start, const ItemInfo &end, bool refresh);
     void resizeClip(const ItemInfo &start, const ItemInfo &end, bool dontWorry = false);
@@ -76,25 +76,24 @@ public:
     void deleteClip(ItemInfo info, bool refresh = true);
     void slotDeleteClipMarker(const QString &comment, const QString &id, const GenTime &position);
     void slotDeleteAllClipMarkers(const QString &id);
-    void addMarker(const QString &id, const CommentedTime marker);
+    void addMarker(const QString &id, const CommentedTime &marker);
     void addData(const QString &id, const QString &key, const QString &data);
     void setScale(double scaleFactor, double verticalScale);
     void deleteClip(const QString &clipId);
     /** @brief An effect was dropped on @param clip */
     void slotDropEffect(ClipItem *clip, QDomElement effect, GenTime pos, int track);
     /** @brief Add effect to current clip */
-    void slotAddEffect(QDomElement effect, GenTime pos, int track);
+    void slotAddEffect(QDomElement effect, const GenTime &pos, int track);
     void slotAddGroupEffect(QDomElement effect, AbstractGroupItem *group, AbstractClipItem *dropTarget = NULL);
     void addEffect(int track, GenTime pos, QDomElement effect);
-    void deleteEffect(int track, GenTime pos, QDomElement effect);
+    void deleteEffect(int track, const GenTime &pos, const QDomElement &effect);
     void updateEffect(int track, GenTime pos, QDomElement insertedEffect, bool refreshEffectStack = false);
     /** @brief Enable / disable a list of effects */
     void updateEffectState(int track, GenTime pos, QList <int> effectIndexes, bool disable, bool updateEffectStack);
-    void moveEffect(int track, GenTime pos, QList <int> oldPos, QList <int> newPos);
-    void addTransition(ItemInfo transitionInfo, int endTrack, QDomElement params, bool refresh);
-    void deleteTransition(ItemInfo transitionInfo, int endTrack, QDomElement params, bool refresh);
-    void updateTransition(int track, GenTime pos,  QDomElement oldTransition, QDomElement transition, bool updateTransitionWidget);
-    void moveTransition(GenTime oldpos, GenTime newpos);
+    void moveEffect(int track, const GenTime &pos, const QList<int> &oldPos, const QList<int> &newPos);
+    void addTransition(const ItemInfo &transitionInfo, int endTrack, const QDomElement &params, bool refresh);
+    void deleteTransition(const ItemInfo &transitionInfo, int endTrack, QDomElement params, bool refresh);
+    void updateTransition(int track, const GenTime &pos,  const QDomElement &oldTransition, const QDomElement &transition, bool updateTransitionWidget);
     void activateMonitor();
     int duration() const;
     void deleteSelectedClips();
@@ -104,8 +103,8 @@ public:
     bool checkTrackHeight();
     void updateSceneFrameWidth();
     //QList <TrackInfo> tracksList() const;
-    void setTool(PROJECTTOOL tool);
-    ClipItem *cutClip(ItemInfo info, GenTime cutTime, bool cut, EffectsList oldStack = EffectsList(), bool execute = true);
+    void setTool(ProjectTool tool);
+    ClipItem *cutClip(const ItemInfo &info, const GenTime &cutTime, bool cut, const EffectsList &oldStack = EffectsList(), bool execute = true);
     void slotSeekToPreviousSnap();
     void slotSeekToNextSnap();
     double getSnapPointForPos(double pos);
@@ -118,7 +117,7 @@ public:
     QList<ItemInfo> findId(const QString &clipId);
     void clipStart();
     void clipEnd();
-    void doChangeClipSpeed(ItemInfo info, ItemInfo speedIndependantInfo, const double speed, const double oldspeed, int strobe, const QString &id);
+    void doChangeClipSpeed(ItemInfo info, const ItemInfo &speedIndependantInfo, const double speed, const double oldspeed, int strobe, const QString &id);
     /** @brief Sets the document as modified. */
     void setDocumentModified();
     void setInPoint();
@@ -162,9 +161,8 @@ public:
     * @param track Track of the clip
     * @param split Split or unsplit */
     void doSplitAudio(const GenTime &pos, int track, EffectsList effects, bool split);
-    void setVideoOnly();
-    void setAudioOnly();
-    void setAudioAndVideo();
+    /** @brief Sets the clip type (av, video only, audio only) of the current selection. */
+    void setClipType(bool videoOnly, bool audioOnly);
     void doChangeClipType(const GenTime &pos, int track, bool videoOnly, bool audioOnly);
     int hasGuide(int pos, int offset);
     void reloadTransitionLumas();
@@ -184,7 +182,7 @@ public:
     void selectClip(bool add, bool group = false, int track = -1, int pos = -1);
     void selectTransition(bool add, bool group = false);
     QStringList extractTransitionsLumas();
-    void setEditMode(EDITMODE mode);
+    void setEditMode(EditMode mode);
 
     /** @brief Inserts @param clip.
     * @param clip The clip to insert
@@ -204,7 +202,7 @@ public:
     * Check whether given track has a clip with audio in it. */
     bool hasAudio(int track) const;
 
-    int getFrameWidth();
+    int getFrameWidth() const;
     /** @brief Returns last requested seeking pos (or SEEK_INACTIVE if no seek). */
     int seekPosition() const;
 
@@ -214,6 +212,9 @@ public:
     /** @brief Returns frame number of current mouse position. */
     int getMousePos() const;
     
+    /** @brief Get effect parameters ready for MLT*/
+    static void adjustEffectParameters(EffectsParameterList &parameters, QDomNodeList params, MltVideoProfile profile, const QString &prefix = QString());
+    
 public slots:
     /** @brief Send seek request to MLT. */
     void seekCursorPos(int pos);
@@ -250,7 +251,7 @@ public slots:
     /** @brief Shows a dialog for adding a guide.
      * @param dialog (default = true) false = do not show the dialog but use current position as position and comment */
     void slotAddGuide(bool dialog = true);
-    void slotEditGuide(CommentedTime guide);
+    void slotEditGuide(const CommentedTime &guide);
     void slotEditGuide(int guidePos = -1);
     void slotDeleteGuide(int guidePos = -1);
     void slotDeleteAllGuides();
@@ -276,7 +277,7 @@ public slots:
     /** @brief Rebuilds a group to fit again after children changed.
     * @param childTrack the track of one of the groups children
     * @param childPos The position of the same child */
-    void rebuildGroup(int childTrack, GenTime childPos);
+    void rebuildGroup(int childTrack, const GenTime &childPos);
     /** @brief Rebuilds a group to fit again after children changed.
     * @param group The group to rebuild */
     void rebuildGroup(AbstractGroupItem *group);
@@ -296,13 +297,14 @@ public slots:
     * @param skipSelectedItems if true, the selected item start and end points will not be added to snap list */
     void updateSnapPoints(AbstractClipItem *selected, QList <GenTime> offsetList = QList <GenTime> (), bool skipSelectedItems = false);
     
-    void slotAddEffect(ClipItem *clip, QDomElement effect);
-    void slotImportClipKeyframes(GRAPHICSRECTITEM type);
+    void slotAddEffect(ClipItem *clip, const QDomElement &effect);
+    void slotImportClipKeyframes(GraphicsRectItem type);
 
-    /** @brief Get effect parameters ready for MLT*/
-    static void adjustEffectParameters(EffectsParameterList &parameters, QDomNodeList params, MltVideoProfile profile, const QString &prefix = QString());
-	/** @brief Move playhead to mouse curser position if defined key is pressed */
+    /** @brief Move playhead to mouse curser position if defined key is pressed */
     void slotAlignPlayheadToMousePos();
+    
+    void slotInfoProcessingFinished();
+    void slotAlignClip(int, int, int);
 
 protected:
     virtual void drawBackground(QPainter * painter, const QRectF & rect);
@@ -327,8 +329,8 @@ private:
     QGraphicsLineItem *m_cursorLine;
     ItemInfo m_dragItemInfo;
     ItemInfo m_selectionGroupInfo;
-    OPERATIONTYPE m_operationMode;
-    OPERATIONTYPE m_moveOpMode;
+    OperationType m_operationMode;
+    OperationType m_moveOpMode;
     AbstractClipItem *m_dragItem;
     Guide *m_dragGuide;
     QUndoStack *m_commandStack;
@@ -373,7 +375,7 @@ private:
     bool m_clipDrag;
 
     int m_findIndex;
-    PROJECTTOOL m_tool;
+    ProjectTool m_tool;
     QCursor m_razorCursor;
     QCursor m_spacerCursor;
     /** list containing items currently copied in the timeline */
@@ -400,7 +402,7 @@ private:
 
     /** Get the index of the video track that is just below current track */
     int getPreviousVideoTrack(int track);
-    void updatePositionEffects(ClipItem * item, ItemInfo info, bool standalone = true);
+    void updatePositionEffects(ClipItem * item, const ItemInfo &info, bool standalone = true);
     bool insertDropClips(const QMimeData *data, const QPoint &pos);
     bool canBePastedTo(QList <ItemInfo> infoList, int type) const;
     bool canBePasted(QList<AbstractClipItem *> items, GenTime offset, int trackOffset) const;
@@ -415,12 +417,12 @@ private:
     void getTransitionAvailableSpace(AbstractClipItem *item, GenTime &minimum, GenTime &maximum);
     void updateClipTypeActions(ClipItem *clip);
     /** Whether an item can be moved to a new position without colliding with similar items */
-    bool itemCollision(AbstractClipItem *item, ItemInfo newPos);
+    bool itemCollision(AbstractClipItem *item, const ItemInfo &newPos);
     /** Selects all items in the scene rect, and sets ok to false if a group going over several tracks is found in it */
     QList<QGraphicsItem *> checkForGroups(const QRectF &rect, bool *ok);
     /** Adjust clips under another one when working in overwrite mode */
-    void adjustTimelineClips(EDITMODE mode, ClipItem *item, ItemInfo posinfo, QUndoCommand *command);
-    void adjustTimelineTransitions(EDITMODE mode, Transition *item, QUndoCommand *command);
+    void adjustTimelineClips(EditMode mode, ClipItem *item, ItemInfo posinfo, QUndoCommand *command);
+    void adjustTimelineTransitions(EditMode mode, Transition *item, QUndoCommand *command);
     /** Adjust keyframes when pasted to another clip */
     void adjustKeyfames(GenTime oldstart, GenTime newstart, GenTime duration, QDomElement xml);
 
@@ -430,7 +432,7 @@ private:
     * @param clip clip to display the tip on
     * @param mode operation mode for which the tip should be displayed
     * @param size size of the tip */
-    void setTipAnimation(AbstractClipItem *clip, OPERATIONTYPE mode, const double size);
+    void setTipAnimation(AbstractClipItem *clip, OperationType mode, const double size);
 
     /** @brief Takes care of updating effects and attached transitions during a resize from start.
     * @param item Item to resize
@@ -522,14 +524,13 @@ signals:
     void playMonitor();
     /** @brief Monitor document changes (for example the presence of audio data in timeline for export widget.*/
     void documentModified();
-    void forceClipProcessing(const QString &);
     void showTrackEffects(int, TrackInfo);
     /** @brief Update the track effect button that shows if a track has effects or not.*/
     void updateTrackEffectState(int);
     /** @brief Cursor position changed, repaint ruler.*/
     void updateRuler();
     /** @brief Send data from a clip to be imported as keyframes for effect / transition.*/
-    void importKeyframes(GRAPHICSRECTITEM type, const QString&, int maximum);
+    void importKeyframes(GraphicsRectItem type, const QString&, int maximum);
 };
 
 #endif
