@@ -22,8 +22,6 @@
 #define DVDWIZARD_H
 
 #include <QWizard>
-#include <QVBoxLayout>
-#include <QItemDelegate>
 #include <QPainter>
 #include <QProcess>
 
@@ -77,7 +75,7 @@ private:
     void cleanup();
     void errorMessage(const QString &text);
     void infoMessage(const QString &text);
-    void processDvdauthor(QString menuMovieUrl = QString(), stringRectMap buttons = stringRectMap(), QStringList buttonsTarget = QStringList());
+    void processDvdauthor(const QString &menuMovieUrl = QString(), const stringRectMap &buttons = stringRectMap(), const QStringList &buttonsTarget = QStringList());
 
 private slots:
     void slotPageChanged(int page);
