@@ -26,13 +26,13 @@
 #include "complexparameter.h"
 #include "geometryval.h"
 #include "positionedit.h"
-#include "kis_curve_widget.h"
+#include "widgets/kis_curve_widget.h"
 #include "kis_cubic_curve.h"
-#include "choosecolorwidget.h"
-#include "geometrywidget.h"
+#include "widgets/choosecolorwidget.h"
+#include "widgets/geometrywidget.h"
 #include "colortools.h"
-#include "doubleparameterwidget.h"
-#include "cornerswidget.h"
+#include "widgets/doubleparameterwidget.h"
+#include "widgets/cornerswidget.h"
 #include "dragvalue.h"
 #include "beziercurve/beziersplinewidget.h"
 #ifdef USE_QJSON
@@ -95,7 +95,7 @@ class Fontval: public QWidget, public Ui::Fontval_UI
 };
 
 
-ParameterContainer::ParameterContainer(QDomElement effect, ItemInfo info, EffectMetaInfo *metaInfo, QWidget * parent) :
+ParameterContainer::ParameterContainer(const QDomElement &effect, const ItemInfo &info, EffectMetaInfo *metaInfo, QWidget * parent) :
         m_keyframeEditor(NULL),
         m_geometryWidget(NULL),
         m_metaInfo(metaInfo),
@@ -121,7 +121,7 @@ ParameterContainer::ParameterContainer(QDomElement effect, ItemInfo info, Effect
     m_vbox->setContentsMargins(4, 0, 4, 0);
     m_vbox->setSpacing(2);
 
-    for (int i = 0; i < namenode.count() ; i++) {
+    for (int i = 0; i < namenode.count() ; ++i) {
         QDomElement pa = namenode.item(i).toElement();
         if (pa.tagName() != "parameter") continue;
         QDomElement na = pa.firstChildElement("name");
@@ -176,7 +176,7 @@ ParameterContainer::ParameterContainer(QDomElement effect, ItemInfo info, Effect
             if (listitemsdisplay.count() != listitems.count())
                 listitemsdisplay = listitems;
             lsval->list->setIconSize(QSize(30, 30));
-            for (int i = 0; i < listitems.count(); i++) {
+            for (int i = 0; i < listitems.count(); ++i) {
                 lsval->list->addItem(listitemsdisplay.at(i), listitems.at(i));
                 QString entry = listitems.at(i);
                 if (!entry.isEmpty() && (entry.endsWith(".png") || entry.endsWith(".pgm"))) {
@@ -219,7 +219,7 @@ ParameterContainer::ParameterContainer(QDomElement effect, ItemInfo info, Effect
         } else if (type == "geometry") {
             if (KdenliveSettings::on_monitor_effects()) {
 		m_needsMonitorEffectScene = true;
-                m_geometryWidget = new GeometryWidget(m_metaInfo->monitor, m_metaInfo->timecode, 0, true, effect.hasAttribute("showrotation"), parent);
+                m_geometryWidget = new GeometryWidget(m_metaInfo->monitor, m_metaInfo->timecode, 0, effect.hasAttribute("showrotation"), parent);
                 m_geometryWidget->setFrameSize(m_metaInfo->frameSize);
                 connect(m_geometryWidget, SIGNAL(parameterChanged()), this, SLOT(slotCollectAllParameters()));
                 if (minFrame == maxFrame) {
@@ -283,7 +283,7 @@ ParameterContainer::ParameterContainer(QDomElement effect, ItemInfo info, Effect
 	    choosecolor->setToolTip(comment);
             m_vbox->addWidget(choosecolor);
             m_valueItems[paramName] = choosecolor;
-            connect(choosecolor, SIGNAL(displayMessage(const QString&, int)), this, SIGNAL(displayMessage(const QString&, int)));
+            connect(choosecolor, SIGNAL(displayMessage(QString,int)), this, SIGNAL(displayMessage(QString,int)));
             connect(choosecolor, SIGNAL(modified()) , this, SLOT(slotCollectAllParameters()));
 	    connect(choosecolor, SIGNAL(disableCurrentFilter(bool)) , this, SIGNAL(disableCurrentFilter(bool)));
         } else if (type == "position") {
@@ -421,7 +421,7 @@ ParameterContainer::ParameterContainer(QDomElement effect, ItemInfo info, Effect
             m_valueItems[paramName] = cval;
             cval->urlwidget->setUrl(KUrl(value));
             connect(cval->urlwidget, SIGNAL(returnPressed()) , this, SLOT(slotCollectAllParameters()));
-            connect(cval->urlwidget, SIGNAL(urlSelected(const KUrl&)) , this, SLOT(slotCollectAllParameters()));
+            connect(cval->urlwidget, SIGNAL(urlSelected(KUrl)) , this, SLOT(slotCollectAllParameters()));
             m_uiItems.append(cval);
 	} else if (type == "keywords") {
             Keywordval* kval = new Keywordval;
@@ -440,7 +440,7 @@ ParameterContainer::ParameterContainer(QDomElement effect, ItemInfo info, Effect
             if (keyworddisplaylist.count() != keywordlist.count()) {
                 keyworddisplaylist = keywordlist;
             }
-            for (int i = 0; i < keywordlist.count(); i++) {
+            for (int i = 0; i < keywordlist.count(); ++i) {
                 kval->comboboxwidget->addItem(keyworddisplaylist.at(i), keywordlist.at(i));
             }
             // Add disabled user prompt at index 0
@@ -449,7 +449,7 @@ ParameterContainer::ParameterContainer(QDomElement effect, ItemInfo info, Effect
             kval->comboboxwidget->setCurrentIndex(0);
             m_valueItems[paramName] = kval;
             connect(kval->lineeditwidget, SIGNAL(editingFinished()) , this, SLOT(slotCollectAllParameters()));
-            connect(kval->comboboxwidget, SIGNAL(activated (const QString&)), this, SLOT(slotCollectAllParameters()));
+            connect(kval->comboboxwidget, SIGNAL(activated(QString)), this, SLOT(slotCollectAllParameters()));
             m_uiItems.append(kval);
         } else if (type == "fontfamily") {
             Fontval* fval = new Fontval;
@@ -457,7 +457,7 @@ ParameterContainer::ParameterContainer(QDomElement effect, ItemInfo info, Effect
             fval->name->setText(paramName);
             fval->fontfamilywidget->setCurrentFont(QFont(value));
             m_valueItems[paramName] = fval;
-            connect(fval->fontfamilywidget, SIGNAL(currentFontChanged(const QFont &)), this, SLOT(slotCollectAllParameters())) ;
+            connect(fval->fontfamilywidget, SIGNAL(currentFontChanged(QFont)), this, SLOT(slotCollectAllParameters())) ;
             m_uiItems.append(fval);
         } else if (type == "filterjob") {
 	    QVBoxLayout *l= new QVBoxLayout(toFillin);
@@ -483,10 +483,10 @@ ParameterContainer::ParameterContainer(QDomElement effect, ItemInfo info, Effect
     // Make sure all doubleparam spinboxes have the same width, looks much better
     QList<DoubleParameterWidget *> allWidgets = findChildren<DoubleParameterWidget *>();
     int minSize = 0;
-    for (int i = 0; i < allWidgets.count(); i++) {
+    for (int i = 0; i < allWidgets.count(); ++i) {
         if (minSize < allWidgets.at(i)->spinSize()) minSize = allWidgets.at(i)->spinSize();
     }
-    for (int i = 0; i < allWidgets.count(); i++) {
+    for (int i = 0; i < allWidgets.count(); ++i) {
         allWidgets.at(i)->setSpinSize(minSize);
     }
 }
@@ -497,12 +497,12 @@ ParameterContainer::~ParameterContainer()
     delete m_vbox;
 }
 
-void ParameterContainer::meetDependency(const QString& name, QString type, QString value)
+void ParameterContainer::meetDependency(const QString& name, const QString &type, const QString &value)
 {
     if (type == "curve") {
         KisCurveWidget *curve = (KisCurveWidget*)m_valueItems[name];
         if (curve) {
-            int color = value.toInt();
+            const int color = value.toInt();
             curve->setPixmap(QPixmap::fromImage(ColorTools::rgbCurvePlane(curve->size(), (ColorTools::ColorsRGB)(color == 3 ? 4 : color), 0.8)));
         }
     } else if (type == "bezier_spline") {
@@ -561,7 +561,7 @@ void ParameterContainer::updateTimecodeFormat()
         m_keyframeEditor->updateTimecodeFormat();
 
     QDomNodeList namenode = m_effect.elementsByTagName("parameter");
-    for (int i = 0; i < namenode.count() ; i++) {
+    for (int i = 0; i < namenode.count() ; ++i) {
         QDomNode pa = namenode.item(i);
         QDomElement na = pa.firstChildElement("name");
         QString type = pa.attributes().namedItem("type").nodeValue();
@@ -597,7 +597,7 @@ void ParameterContainer::slotCollectAllParameters()
     //QDomElement newparam = oldparam.cloneNode().toElement();
     QDomNodeList namenode = m_effect.elementsByTagName("parameter");
 
-    for (int i = 0; i < namenode.count() ; i++) {
+    for (int i = 0; i < namenode.count() ; ++i) {
         QDomElement pa = namenode.item(i).toElement();
         QDomElement na = pa.firstChildElement("name");
         QString type = pa.attribute("type");
@@ -620,10 +620,10 @@ void ParameterContainer::slotCollectAllParameters()
             DoubleParameterWidget *doubleparam = (DoubleParameterWidget*)m_valueItems.value(paramName);
             setValue = locale.toString(doubleparam->getValue());
         } else if (type == "list") {
-            KComboBox *box = ((Listval*)m_valueItems.value(paramName))->list;
+            KComboBox *box = static_cast<Listval*>(m_valueItems.value(paramName))->list;
             setValue = box->itemData(box->currentIndex()).toString();
         } else if (type == "bool") {
-            QCheckBox *box = ((Boolval*)m_valueItems.value(paramName))->checkBox;
+            QCheckBox *box = static_cast<Boolval*>(m_valueItems.value(paramName))->checkBox;
             setValue = box->checkState() == Qt::Checked ? "1" : "0" ;
         } else if (type == "color") {
             ChooseColorWidget *choosecolor = ((ChooseColorWidget*)m_valueItems.value(paramName));
@@ -700,7 +700,7 @@ void ParameterContainer::slotCollectAllParameters()
             setValue = widget->getSpline();
 #endif
         } else if (type == "wipe") {
-            Wipeval *wp = (Wipeval*)m_valueItems.value(paramName);
+            Wipeval *wp = static_cast<Wipeval*>(m_valueItems.value(paramName));
             wipeInfo info;
             if (wp->start_left->isChecked())
                 info.start = LEFT;
@@ -742,11 +742,11 @@ void ParameterContainer::slotCollectAllParameters()
             else if (pa.hasAttribute("intimeline"))
                 pa.setAttribute("intimeline", "0");
         } else if (type == "url") {
-            KUrlRequester *req = ((Urlval*)m_valueItems.value(paramName))->urlwidget;
+            KUrlRequester *req = static_cast<Urlval*>(m_valueItems.value(paramName))->urlwidget;
             setValue = req->url().path();
 	} else if (type == "keywords"){
-            QLineEdit *line = ((Keywordval*)m_valueItems.value(paramName))->lineeditwidget;
-            QComboBox *combo = ((Keywordval*)m_valueItems.value(paramName))->comboboxwidget;
+            QLineEdit *line = static_cast<Keywordval*>(m_valueItems.value(paramName))->lineeditwidget;
+            QComboBox *combo = static_cast<Keywordval*>(m_valueItems.value(paramName))->comboboxwidget;
             if(combo->currentIndex())
             {
                 QString comboval = combo->itemData(combo->currentIndex()).toString();
@@ -755,7 +755,7 @@ void ParameterContainer::slotCollectAllParameters()
             }
             setValue = line->text();
         } else if (type == "fontfamily") {
-            QFontComboBox* fontfamily = ((Fontval*)m_valueItems.value(paramName))->fontfamilywidget;
+            QFontComboBox* fontfamily = static_cast<Fontval*>(m_valueItems.value(paramName))->fontfamilywidget;
             setValue = fontfamily->currentFont().family();
         }
         if (!setValue.isNull())
@@ -818,7 +818,7 @@ void ParameterContainer::updateParameter(const QString &key, const QString &valu
 void ParameterContainer::slotStartFilterJobAction()
 {
     QDomNodeList namenode = m_effect.elementsByTagName("parameter");
-    for (int i = 0; i < namenode.count() ; i++) {
+    for (int i = 0; i < namenode.count() ; ++i) {
         QDomElement pa = namenode.item(i).toElement();
         QString type = pa.attribute("type");
         if (type == "filterjob") {
@@ -889,3 +889,5 @@ void ParameterContainer::setRange(int inPoint, int outPoint)
 }
 
 
+
+#include "parametercontainer.moc"
