@@ -9,7 +9,6 @@
  ***************************************************************************/
 
 #include "audioCorrelationInfo.h"
-#include <iostream>
 
 
 AudioCorrelationInfo::AudioCorrelationInfo(int mainSize, int subSize) :
@@ -40,7 +39,7 @@ int64_t AudioCorrelationInfo::max() const
     if (m_max <= 0) {
         int width = size();
         int64_t max = 0;
-        for (int i = 0; i < width; i++) {
+        for (int i = 0; i < width; ++i) {
             if (m_correlationVector[i] > max) {
                 max = m_correlationVector[i];
             }
@@ -57,7 +56,7 @@ int AudioCorrelationInfo::maxIndex() const
     int index = 0;
     int width = size();
 
-    for (int i = 0; i < width; i++) {
+    for (int i = 0; i < width; ++i) {
         if (m_correlationVector[i] > max) {
             max = m_correlationVector[i];
             index = i;
