@@ -48,7 +48,7 @@
 #include "statusbarmessagelabel.h"
 #include "dvdwizard.h"
 #include "stopmotion/stopmotion.h"
-#include "noteswidget.h"
+#include "widgets/noteswidget.h"
 #include "ui_backupdialog_ui.h"
 
 class KdenliveDoc;
@@ -61,7 +61,6 @@ class EffectStackView2;
 class TransitionSettings;
 class Monitor;
 class RecMonitor;
-class CustomTrackView;
 class RenderWidget;
 #ifdef USE_JOGSHUTTLE
 class JogShuttle;
@@ -77,7 +76,6 @@ class Waveform;
 class RGBParade;
 class KActionCollection;
 class AudioSignal;
-class AbstractAudioScopeWidget;
 class AudioSpectrum;
 class Spectrogram;
 
@@ -242,9 +240,6 @@ private:
     KAction *m_projectSearch;
     KAction *m_projectSearchNext;
 
-    KAction **m_videoEffects;
-    KAction **m_audioEffects;
-    KAction **m_customEffects;
     KAction **m_transitions;
     KAction *m_buttonAudioThumbs;
     KAction *m_buttonVideoThumbs;
@@ -284,7 +279,7 @@ private:
     void connectDocumentInfo(KdenliveDoc *doc);
     void findAhead();
     void doOpenFile(const KUrl &url, KAutoSaveFile *stale);
-    void recoverFiles(QList<KAutoSaveFile *> staleFiles, const KUrl &originUrl);
+    void recoverFiles(const QList<KAutoSaveFile *> &staleFiles, const KUrl &originUrl);
 
     /** @brief Loads static and dynamic plugins.
      *
@@ -366,7 +361,7 @@ private slots:
     void slotUpdateClip(const QString &id);
     void slotUpdateMousePosition(int pos);
     void slotUpdateProjectDuration(int pos);
-    void slotAddEffect(const QDomElement effect);
+    void slotAddEffect(const QDomElement &effect);
     void slotEditProfiles();
     void slotDetectAudioDriver();
     void slotEditProjectSettings();
@@ -427,16 +422,16 @@ private slots:
     void slotSelectAddTimelineTransition();
     void slotAddVideoEffect(QAction *result);
     void slotAddTransition(QAction *result);
-    void slotAddProjectClip(KUrl url, stringMap data = stringMap());
-    void slotAddProjectClipList(KUrl::List urls);
+    void slotAddProjectClip(const KUrl &url, const stringMap &data = stringMap());
+    void slotAddProjectClipList(const KUrl::List &urls);
     void slotShowClipProperties(DocClipBase *clip);
-    void slotShowClipProperties(QList <DocClipBase *>cliplist, QMap<QString, QString> commonproperties);
+    void slotShowClipProperties(const QList<DocClipBase *> &cliplist, const QMap<QString, QString> &commonproperties);
     void slotTimelineClipSelected(ClipItem* item, bool raise = true);
-    void slotTrackSelected(int index, TrackInfo info, bool raise = true);
-    void slotActivateTransitionView(Transition *);
+    void slotTrackSelected(int index, const TrackInfo &info, bool raise = true);
+    void slotActivateTransitionView(Transition *transition);
     void slotChangeTool(QAction * action);
     void slotChangeEdit(QAction * action);
-    void slotSetTool(PROJECTTOOL tool);
+    void slotSetTool(ProjectTool tool);
     void slotSnapForward();
     void slotSnapRewind();
     void slotClipStart();
@@ -463,7 +458,7 @@ private slots:
 
     void slotAdjustClipMonitor();
     void slotAdjustProjectMonitor();
-    void slotSaveZone(Render *render, QPoint zone, DocClipBase *baseClip = NULL, KUrl path = KUrl());
+    void slotSaveZone(Render *render, const QPoint &zone, DocClipBase *baseClip = NULL, KUrl path = KUrl());
 
     void slotSetInPoint();
     void slotSetOutPoint();
@@ -499,12 +494,12 @@ private slots:
     void slotUpdateClipType(QAction *action);
     void slotShowTimeline(bool show);
     void slotMaximizeCurrent(bool show);
-    void slotTranscode(KUrl::List urls = KUrl::List());
+    void slotTranscode(const KUrl::List &urls = KUrl::List());
     void slotStartClipAction();
     void slotTranscodeClip();
     /** @brief Archive project: creates a copy of the project file with all clips in a new folder. */
     void slotArchiveProject();
-    void slotSetDocumentRenderProfile(QMap <QString, QString> props);
+    void slotSetDocumentRenderProfile(const QMap<QString, QString> &props);
     void slotPrepareRendering(bool scriptExport, bool zoneOnly, const QString &chapterFile);
 
     /** @brief Switches between displaying frames or timecode.
@@ -529,14 +524,14 @@ private slots:
     /** @brief Deletes items from timeline and document.
     * @param ids The ids of the clips to delete.
     * @param folderids The names and ids of the folders to delete. */
-    void slotDeleteProjectClips(QStringList ids, QMap<QString, QString> folderids);
+    void slotDeleteProjectClips(const QStringList &ids, const QMap<QString, QString> &folderids);
     void slotShowTitleBars(bool show);
     void slotSwitchTitles();
     /** @brief Update the capture folder if user asked a change. */
     void slotUpdateCaptureFolder();
 
     /** @brief Apply new properties to a clip */
-    void slotApplyNewClipProperties(const QString id, QMap <QString, QString> props, QMap <QString, QString> newprops, bool refresh, bool reload);
+    void slotApplyNewClipProperties(const QString &id, const QMap <QString, QString> &props, const QMap <QString, QString> &newprops, bool refresh, bool reload);
 
     /** @brief Delete a clip from current project */
     void slotDeleteClip(const QString &id);
@@ -556,7 +551,7 @@ private slots:
     /** @brief Insert current project's timecode into the notes widget. */
     void slotInsertNotesTimecode();
     /** @brief Open the project's backupdialog. */
-    void slotOpenBackupDialog(const KUrl url = KUrl());
+    void slotOpenBackupDialog(const KUrl &url = KUrl());
     /** @brief Disable proxies for this project. */
     void slotDisableProxies();
 
@@ -568,7 +563,7 @@ private slots:
     /** @brief Save current timeline clip as mlt playlist. */
     void slotSaveTimelineClip();
     /** @brief Process keyframe data sent from a clip to effect / transition stack. */
-    void slotProcessImportKeyframes(GRAPHICSRECTITEM type, const QString& data, int maximum);
+    void slotProcessImportKeyframes(GraphicsRectItem type, const QString& data, int maximum);
     /** @brief Move playhead to mouse curser position if defined key is pressed */
     void slotAlignPlayheadToMousePos();
     /** @brief Set MLT's consumer deinterlace method */
