@@ -41,8 +41,8 @@ class DocClipBase;
 class ProjectItem : public QTreeWidgetItem
 {
 public:
-    ProjectItem(QTreeWidget * parent, DocClipBase *clip, QSize pixmapSize);
-    ProjectItem(QTreeWidgetItem * parent, DocClipBase *clip, QSize pixmapSize);
+    ProjectItem(QTreeWidget * parent, DocClipBase *clip, const QSize &pixmapSize);
+    ProjectItem(QTreeWidgetItem * parent, DocClipBase *clip, const QSize &pixmapSize);
     virtual ~ProjectItem();
     QDomElement toXml() const;
     int numReferences() const;
@@ -55,19 +55,19 @@ public:
     const QString &clipId() const;
     const KUrl clipUrl() const;
     int clipMaxDuration() const;
-    CLIPTYPE clipType() const;
+    ClipType clipType() const;
     void changeDuration(int frames);
     DocClipBase *referencedClip();
-    void setProperties(QMap <QString, QString> props);
+    void setProperties(const QMap <QString, QString> &props);
     void setProperty(const QString &key, const QString &value);
     void clearProperty(const QString &key);
     QString getClipHash() const;
     static int itemDefaultHeight();
     void slotSetToolTip();
     /** \brief Set the status of the clip job. */
-    void setJobStatus(JOBTYPE jobType, CLIPJOBSTATUS status, int progress = 0, const QString &statusMessage = QString());
+    void setJobStatus(JOBTYPE jobType, ClipJobStatus status, int progress = 0, const QString &statusMessage = QString());
     /** \brief Set the status of a clip job if it is of the specified job type. */
-    void setConditionalJobStatus(CLIPJOBSTATUS status, JOBTYPE requestedJobType);
+    void setConditionalJobStatus(ClipJobStatus status, JOBTYPE requestedJobType);
     /** \brief Returns the proxy status for this clip (true means there is a proxy clip). */
     bool hasProxy() const;
     /** \brief Returns true if the proxy for this clip is ready. */
@@ -79,24 +79,24 @@ public:
     /** \brief Returns true if the thumbnail for this clip has been loaded. */
     bool hasPixmap() const;
     /** \brief Sets the thumbnail for this clip. */
-    void setPixmap(const QPixmap p);
+    void setPixmap(const QPixmap& p);
 
     virtual bool operator<(const QTreeWidgetItem &other)const {
         int column = treeWidget()->sortColumn();
-        if (other.type() != PROJECTFOLDERTYPE)
+        if (other.type() != ProjectFoldeType)
             return text(column).toLower() < other.text(column).toLower();
         else return false;
     }
 
 private:
-    CLIPTYPE m_clipType;
+    ClipType m_clipType;
     DocClipBase *m_clip;
     QString m_clipId;
     bool m_pixmapSet;
     /** @brief Setup basic properties */
-    void buildItem(QSize pixmapSize);
+    void buildItem(const QSize &pixmapSize);
     /** @brief Check if an xml project file has proxies */
-    bool playlistHasProxies(const QString path);
+    bool playlistHasProxies(const QString& path);
 };
 
 #endif
