@@ -8,19 +8,20 @@
  *   (at your option) any later version.                                   *
  ***************************************************************************/
 
-#include "qtconcurrentrun.h"
+#include "QtCore/qtconcurrentrun.h"
 
 #include "abstractscopewidget.h"
 #include "renderer.h"
-#include "monitor.h"
+#include "monitor/monitor.h"
 
-#include <QFuture>
 #include <QColor>
 #include <QMenu>
 #include <QMouseEvent>
 #include <QPainter>
 
 #include <KConfigGroup>
+#include <KGlobal>
+#include <KSharedConfig>
 
 // Uncomment for Scope debugging.
 //#define DEBUG_ASW
@@ -50,21 +51,24 @@ const QPen AbstractScopeWidget::penBackground(QBrush(dark2),
 const QString AbstractScopeWidget::directions[] =  {"North", "Northeast", "East", "Southeast"};
 
 AbstractScopeWidget::AbstractScopeWidget(bool trackMouse, QWidget *parent) :
-        QWidget(parent),
-        m_mousePos(0, 0),
-        m_mouseWithinWidget(false),
-        offset(5),
-        m_accelFactorHUD(1),
-        m_accelFactorScope(1),
-        m_accelFactorBackground(1),
-        m_semaphoreHUD(1),
-        m_semaphoreScope(1),
-        m_semaphoreBackground(1),
-        initialDimensionUpdateDone(false),
-        m_requestForcedUpdate(false),
-        m_rescaleMinDist(4),
-        m_rescaleVerticalThreshold(2.0f),
-        m_rescaleActive(false)
+        QWidget(parent)
+        , m_mousePos(0, 0)
+        , m_mouseWithinWidget(false)
+        , offset(5)
+        , m_accelFactorHUD(1)
+        , m_accelFactorScope(1)
+        , m_accelFactorBackground(1)
+        , m_semaphoreHUD(1)
+        , m_semaphoreScope(1)
+        , m_semaphoreBackground(1)
+        , initialDimensionUpdateDone(false)
+        , m_requestForcedUpdate(false)
+        , m_rescaleMinDist(4)
+        , m_rescaleVerticalThreshold(2.0f)
+        , m_rescaleActive(false)
+	, m_rescalePropertiesLocked(false)
+	, m_rescaleFirstRescaleDone(true)
+	, m_rescaleDirection(North)
 
 {
     m_scopePalette = QPalette();
@@ -90,15 +94,13 @@ AbstractScopeWidget::AbstractScopeWidget(bool trackMouse, QWidget *parent) :
 
     this->setContextMenuPolicy(Qt::CustomContextMenu);
 
-    bool b = true;
-    b &= connect(this, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(customContextMenuRequested(QPoint)));
+    connect(this, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(customContextMenuRequested(QPoint)));
 
-    b &= connect(this, SIGNAL(signalHUDRenderingFinished(uint, uint)), this, SLOT(slotHUDRenderingFinished(uint, uint)));
-    b &= connect(this, SIGNAL(signalScopeRenderingFinished(uint, uint)), this, SLOT(slotScopeRenderingFinished(uint, uint)));
-    b &= connect(this, SIGNAL(signalBackgroundRenderingFinished(uint, uint)), this, SLOT(slotBackgroundRenderingFinished(uint, uint)));
-    b &= connect(m_aRealtime, SIGNAL(toggled(bool)), this, SLOT(slotResetRealtimeFactor(bool)));
-    b &= connect(m_aAutoRefresh, SIGNAL(toggled(bool)), this, SLOT(slotAutoRefreshToggled(bool)));
-    Q_ASSERT(b);
+    connect(this, SIGNAL(signalHUDRenderingFinished(uint,uint)), this, SLOT(slotHUDRenderingFinished(uint,uint)));
+    connect(this, SIGNAL(signalScopeRenderingFinished(uint,uint)), this, SLOT(slotScopeRenderingFinished(uint,uint)));
+    connect(this, SIGNAL(signalBackgroundRenderingFinished(uint,uint)), this, SLOT(slotBackgroundRenderingFinished(uint,uint)));
+    connect(m_aRealtime, SIGNAL(toggled(bool)), this, SLOT(slotResetRealtimeFactor(bool)));
+    connect(m_aAutoRefresh, SIGNAL(toggled(bool)), this, SLOT(slotAutoRefreshToggled(bool)));
 
     // Enable mouse tracking if desired.
     // Causes the mouseMoved signal to be emitted when the mouse moves inside the
@@ -416,8 +418,8 @@ void AbstractScopeWidget::slotHUDRenderingFinished(uint mseconds, uint oldFactor
     m_semaphoreHUD.release(1);
     this->update();
 
-    int accel;
     if (m_aRealtime->isChecked()) {
+        int accel;
         accel = calculateAccelFactorHUD(mseconds, oldFactor);
         if (m_accelFactorHUD < 1) {
             accel = 1;
@@ -450,8 +452,8 @@ void AbstractScopeWidget::slotScopeRenderingFinished(uint mseconds, uint oldFact
     this->update();
 
     // Calculate the acceleration factor hint to get «realtime» updates.
-    int accel;
     if (m_aRealtime->isChecked()) {
+        int accel;
         accel = calculateAccelFactorScope(mseconds, oldFactor);
         if (accel < 1) {
             // If mseconds happens to be 0.
@@ -483,8 +485,8 @@ void AbstractScopeWidget::slotBackgroundRenderingFinished(uint mseconds, uint ol
     m_semaphoreBackground.release(1);
     this->update();
 
-    int accel;
     if (m_aRealtime->isChecked()) {
+        int accel;
         accel = calculateAccelFactorBackground(mseconds, oldFactor);
         if (m_accelFactorBackground < 1) {
             accel = 1;
@@ -562,3 +564,5 @@ void AbstractScopeWidget::handleMouseDrag(const QPoint &, const RescaleDirection
 #ifdef DEBUG_ASW
 #undef DEBUG_ASW
 #endif
+
+#include "abstractscopewidget.moc"
