@@ -12,16 +12,13 @@
 #define ABSTRACTAUDIOSCOPEWIDGET_H
 
 
-#include <QtCore>
 #include <QWidget>
 
 #include <stdint.h>
 
 #include "../abstractscopewidget.h"
 
-class QMenu;
 
-class Monitor;
 class Render;
 
 /**
@@ -35,7 +32,7 @@ public:
     virtual ~AbstractAudioScopeWidget();
 
 public slots:
-    void slotReceiveAudio(QVector<int16_t> sampleData, int freq, int num_channels, int num_samples);
+    void slotReceiveAudio(const QVector<int16_t> &sampleData, int freq, int num_channels, int num_samples);
 
 protected:
     /** @brief This is just a wrapper function, subclasses can use renderAudioScope. */
@@ -46,8 +43,8 @@ protected:
         when calculation has finished, to allow multi-threading.
         accelerationFactor hints how much faster than usual the calculation should be accomplished, if possible. */
     virtual QImage renderAudioScope(uint accelerationFactor,
-                               const QVector<int16_t> audioFrame, const int freq, const int num_channels, const int num_samples,
-                               const int newData) = 0;
+                                    const QVector<int16_t> &audioFrame, const int freq, const int num_channels, const int num_samples,
+                                    const int newData) = 0;
 
     int m_freq;
     int m_nChannels;
