@@ -13,7 +13,7 @@
 #include <QDockWidget>
 
 #include "definitions.h"
-#include "monitormanager.h"
+#include "monitor/monitormanager.h"
 #include "kdenlivesettings.h"
 
 //#define DEBUG_SM
@@ -27,11 +27,9 @@ ScopeManager::ScopeManager(MonitorManager *monitorManager) :
 {
     m_signalMapper = new QSignalMapper(this);
 
-    bool b = true;
-    b &= connect(m_monitorManager, SIGNAL(checkColorScopes()), this, SLOT(slotUpdateActiveRenderer()));
-    b &= connect(m_monitorManager, SIGNAL(clearScopes()), this, SLOT(slotClearColorScopes()));
-    b &= connect(m_signalMapper, SIGNAL(mapped(QString)), this, SLOT(slotRequestFrame(QString)));
-    Q_ASSERT(b);
+    connect(m_monitorManager, SIGNAL(checkColorScopes()), this, SLOT(slotUpdateActiveRenderer()));
+    connect(m_monitorManager, SIGNAL(clearScopes()), this, SLOT(slotClearColorScopes()));
+    connect(m_signalMapper, SIGNAL(mapped(QString)), this, SLOT(slotRequestFrame(QString)));
 
     slotUpdateActiveRenderer();
 }
@@ -41,7 +39,7 @@ bool ScopeManager::addScope(AbstractAudioScopeWidget *audioScope, QDockWidget *a
     bool added = false;
     int exists = false;
     // Only add the scope if it does not exist yet in the list
-    for (int i = 0; i < m_audioScopes.size(); i++) {
+    for (int i = 0; i < m_audioScopes.size(); ++i) {
         if (m_audioScopes[i].scope == audioScope) {
             exists = true;
             break;
@@ -60,14 +58,11 @@ bool ScopeManager::addScope(AbstractAudioScopeWidget *audioScope, QDockWidget *a
         asd.scopeDockWidget = audioScopeWidget;
         m_audioScopes.append(asd);
 
-        bool b = true;
-        b &= connect(audioScope, SIGNAL(requestAutoRefresh(bool)), this, SLOT(slotCheckActiveScopes()));
-//         b &= connect(audioScope, SIGNAL(signalFrameRequest(QString)), this, SLOT(slotRequestFrame(QString)));
+        connect(audioScope, SIGNAL(requestAutoRefresh(bool)), this, SLOT(slotCheckActiveScopes()));
         if (audioScopeWidget != NULL) {
-            b &= connect(audioScopeWidget, SIGNAL(visibilityChanged(bool)), this, SLOT(slotCheckActiveScopes()));
-            b &= connect(audioScopeWidget, SIGNAL(visibilityChanged(bool)), m_signalMapper, SLOT(map()));
+            connect(audioScopeWidget, SIGNAL(visibilityChanged(bool)), this, SLOT(slotCheckActiveScopes()));
+            connect(audioScopeWidget, SIGNAL(visibilityChanged(bool)), m_signalMapper, SLOT(map()));
         }
-        Q_ASSERT(b);
 
         added = true;
     }
@@ -77,7 +72,7 @@ bool ScopeManager::addScope(AbstractGfxScopeWidget *colorScope, QDockWidget *col
 {
     bool added = false;
     int exists = false;
-    for (int i = 0; i < m_colorScopes.size(); i++) {
+    for (int i = 0; i < m_colorScopes.size(); ++i) {
         if (m_colorScopes[i].scope == colorScope) {
             exists = true;
             break;
@@ -95,14 +90,12 @@ bool ScopeManager::addScope(AbstractGfxScopeWidget *colorScope, QDockWidget *col
         gsd.scopeDockWidget = colorScopeWidget;
         m_colorScopes.append(gsd);
 
-        bool b = true;
-        b &= connect(colorScope, SIGNAL(requestAutoRefresh(bool)), this, SLOT(slotCheckActiveScopes()));
-        b &= connect(colorScope, SIGNAL(signalFrameRequest(QString)), this, SLOT(slotRequestFrame(QString)));
+        connect(colorScope, SIGNAL(requestAutoRefresh(bool)), this, SLOT(slotCheckActiveScopes()));
+        connect(colorScope, SIGNAL(signalFrameRequest(QString)), this, SLOT(slotRequestFrame(QString)));
         if (colorScopeWidget != NULL) {
-            b &= connect(colorScopeWidget, SIGNAL(visibilityChanged(bool)), this, SLOT(slotCheckActiveScopes()));
-            b &= connect(colorScopeWidget, SIGNAL(visibilityChanged(bool)), m_signalMapper, SLOT(map()));
+            connect(colorScopeWidget, SIGNAL(visibilityChanged(bool)), this, SLOT(slotCheckActiveScopes()));
+            connect(colorScopeWidget, SIGNAL(visibilityChanged(bool)), m_signalMapper, SLOT(map()));
         }
-        Q_ASSERT(b);
 
         added = true;
     }
@@ -110,12 +103,12 @@ bool ScopeManager::addScope(AbstractGfxScopeWidget *colorScope, QDockWidget *col
 }
 
 
-void ScopeManager::slotDistributeAudio(QVector<int16_t> sampleData, int freq, int num_channels, int num_samples)
+void ScopeManager::slotDistributeAudio(const QVector<int16_t> &sampleData, int freq, int num_channels, int num_samples)
 {
 #ifdef DEBUG_SM
     qDebug() << "ScopeManager: Starting to distribute audio.";
 #endif
-    for (int i = 0; i < m_audioScopes.size(); i++) {
+    for (int i = 0; i < m_audioScopes.size(); ++i) {
         // Distribute audio to all scopes that are visible and want to be refreshed
         if (!m_audioScopes[i].scope->visibleRegion().isEmpty()) {
             if (m_audioScopes[i].scope->autoRefreshEnabled()) {
@@ -129,12 +122,12 @@ void ScopeManager::slotDistributeAudio(QVector<int16_t> sampleData, int freq, in
 
     checkActiveAudioScopes();
 }
-void ScopeManager::slotDistributeFrame(const QImage image)
+void ScopeManager::slotDistributeFrame(const QImage &image)
 {
 #ifdef DEBUG_SM
     qDebug() << "ScopeManager: Starting to distribute frame.";
 #endif
-    for (int i = 0; i < m_colorScopes.size(); i++) {
+    for (int i = 0; i < m_colorScopes.size(); ++i) {
         if (!m_colorScopes[i].scope->visibleRegion().isEmpty()) {
             if (m_colorScopes[i].scope->autoRefreshEnabled()) {
                 m_colorScopes[i].scope->slotRenderZoneUpdated(image);
@@ -158,7 +151,7 @@ void ScopeManager::slotDistributeFrame(const QImage image)
 }
 
 
-void ScopeManager::slotRequestFrame(const QString widgetName)
+void ScopeManager::slotRequestFrame(const QString &widgetName)
 {
 #ifdef DEBUG_SM
     qDebug() << "ScopeManager: New frame was requested by " << widgetName;
@@ -166,13 +159,13 @@ void ScopeManager::slotRequestFrame(const QString widgetName)
 
     // Search for the scope in the lists and tag it to trigger a forced update
     // in the distribution slots
-    for (int i = 0; i < m_colorScopes.size(); i++) {
+    for (int i = 0; i < m_colorScopes.size(); ++i) {
         if (m_colorScopes[i].scope->widgetName() == widgetName) {
             m_colorScopes[i].singleFrameRequested = true;
             break;
         }
     }
-    for (int i = 0; i < m_audioScopes.size(); i++) {
+    for (int i = 0; i < m_audioScopes.size(); ++i) {
         if (m_audioScopes[i].scope->widgetName() == widgetName) {
             m_audioScopes[i].singleFrameRequested = true;
             break;
@@ -190,28 +183,24 @@ void ScopeManager::slotClearColorScopes()
 
 void ScopeManager::slotUpdateActiveRenderer()
 {
-    bool b = true;
-
     // Disconnect old connections
     if (m_lastConnectedRenderer != NULL) {
 #ifdef DEBUG_SM
         qDebug() << "Disconnected previous renderer: " << m_lastConnectedRenderer->name();
 #endif
-        b &= m_lastConnectedRenderer->disconnect(this);
-        Q_ASSERT(b);
+        m_lastConnectedRenderer->disconnect(this);
     }
 
     m_lastConnectedRenderer = m_monitorManager->activeRenderer();
     // DVD monitor shouldn't be monitored or will cause crash on deletion
-    if (m_monitorManager->isActive(Kdenlive::dvdMonitor)) m_lastConnectedRenderer = NULL;
+    if (m_monitorManager->isActive(Kdenlive::DvdMonitor)) m_lastConnectedRenderer = NULL;
 
     // Connect new renderer
     if (m_lastConnectedRenderer != NULL) {
-        b &= connect(m_lastConnectedRenderer, SIGNAL(frameUpdated(const QImage)),
-                this, SLOT(slotDistributeFrame(const QImage)), Qt::UniqueConnection);
-        b &= connect(m_lastConnectedRenderer, SIGNAL(audioSamplesSignal(QVector<int16_t>,int,int,int)),
+        connect(m_lastConnectedRenderer, SIGNAL(frameUpdated(QImage)),
+                this, SLOT(slotDistributeFrame(QImage)), Qt::UniqueConnection);
+        connect(m_lastConnectedRenderer, SIGNAL(audioSamplesSignal(QVector<int16_t>,int,int,int)),
                 this, SLOT(slotDistributeAudio(QVector<int16_t>,int,int,int)), Qt::UniqueConnection);
-        Q_ASSERT(b);
 
 #ifdef DEBUG_SM
         qDebug() << "Renderer connected to ScopeManager: " << m_lastConnectedRenderer->name();
@@ -240,7 +229,7 @@ void ScopeManager::slotCheckActiveScopes()
 bool ScopeManager::audioAcceptedByScopes() const
 {
     bool accepted = false;
-    for (int i = 0; i < m_audioScopes.size(); i++) {
+    for (int i = 0; i < m_audioScopes.size(); ++i) {
         if (!m_audioScopes[i].scope->visibleRegion().isEmpty() && m_audioScopes[i].scope->autoRefreshEnabled()) {
             accepted = true;
             break;
@@ -254,7 +243,7 @@ bool ScopeManager::audioAcceptedByScopes() const
 bool ScopeManager::imagesAcceptedByScopes() const
 {
     bool accepted = false;
-    for (int i = 0; i < m_colorScopes.size(); i++) {
+    for (int i = 0; i < m_colorScopes.size(); ++i) {
         if (!m_colorScopes[i].scope->visibleRegion().isEmpty() && m_colorScopes[i].scope->autoRefreshEnabled()) {
             accepted = true;
             break;
@@ -289,16 +278,18 @@ void ScopeManager::checkActiveColourScopes()
 
     // Notify monitors whether frames are still required
     Monitor *monitor;
-    monitor = static_cast<Monitor*>( m_monitorManager->monitor(Kdenlive::projectMonitor) );
+    monitor = static_cast<Monitor*>( m_monitorManager->monitor(Kdenlive::ProjectMonitor) );
     if (monitor != NULL) { 
 	if (monitor->effectSceneDisplayed()) monitor->render->sendFrameForAnalysis = true;
 	else monitor->render->sendFrameForAnalysis = imageStillRequested;
     }
 
-    monitor = static_cast<Monitor*>( m_monitorManager->monitor(Kdenlive::clipMonitor) );
+    monitor = static_cast<Monitor*>( m_monitorManager->monitor(Kdenlive::ClipMonitor) );
     if (monitor != NULL) { monitor->render->sendFrameForAnalysis = imageStillRequested; }
 
-    RecMonitor *recMonitor = static_cast<RecMonitor*>( m_monitorManager->monitor(Kdenlive::recordMonitor) );
+    RecMonitor *recMonitor = static_cast<RecMonitor*>( m_monitorManager->monitor(Kdenlive::RecordMonitor) );
     if (recMonitor != NULL) { recMonitor->analyseFrames(imageStillRequested); }
 }
 
+
+#include "scopemanager.moc"
