@@ -32,7 +32,7 @@ class V4lCaptureHandler
 
 public:
     V4lCaptureHandler();
-    static QStringList getDeviceName(QString input);
+    static QStringList getDeviceName(const QString &input);
 
 };
 
